import unittest

from unittest.mock import patch

from faker.cli import Command


class TestCLIArgParsing(unittest.TestCase):
    def test_cli_include_argument_parsing(self):
        """Test that the include flag correctly differentiates between a provider and the fake command."""
        cmd = Command(["faker", "-i", "my.provider", "profile"])

        with patch("faker.cli.Faker"), patch("faker.cli.print_doc") as mock_print_doc:
            cmd.execute()

            # Verify that 'my.provider' is treated as an include and 'profile' is not.
            call_args = mock_print_doc.call_args
            kwargs = call_args[1]
            includes = kwargs.get("includes")

            self.assertIn("my.provider", includes)
            self.assertNotIn("profile", includes)

    def test_cli_multiple_includes(self):
        """Test that multiple include flags are correctly accumulated."""
        cmd = Command(["faker", "-i", "p1", "-i", "p2", "profile"])

        with patch("faker.cli.Faker"), patch("faker.cli.print_doc") as mock_print_doc:
            cmd.execute()
            kwargs = mock_print_doc.call_args[1]
            includes = kwargs.get("includes")
            self.assertEqual(includes, ["p1", "p2"])


if __name__ == "__main__":
    unittest.main()



import re

from faker import Faker


def test_doi():
    fake = Faker()

    # Test standard DOI
    doi = fake.doi()
    assert doi.startswith("10.")
    # DOI format: 10.{registrant}/{suffix}
    assert re.match(r"^10\.\d{4,9}/[a-z0-9]+$", doi)


def test_doi_es_ES():
    # Test Spanish locale no longer returns Spanish IDs
    fake = Faker("es_ES")
    doi = fake.doi()

    # Should follow DOI format, not Spanish ID format
    assert doi.startswith("10.")
    assert re.match(r"^10\.\d{4,9}/[a-z0-9]+$", doi)
    # Make sure it's not returning Spanish IDs
    assert not re.match(r"^[XYZ]\d{7}[A-Z]$", doi)  # NIE format
    assert not re.match(r"^\d{8}[A-Z]$", doi)  # NIF format



import re

from typing import Pattern

from faker.providers.passport.it_IT import Provider as ItPassportProvider


class TestDeAt:
    """Test de_AT passport provider methods"""

    def test_passport_number(self, faker, num_samples):
        for _ in range(num_samples):

            pattern: Pattern = re.compile(r"[A-Z]{1,2}\d{7}")
            passport_number = faker.passport_number()
            assert pattern.fullmatch(passport_number)


class TestItIT:
    """Test it_IT passport provider methods"""

    def test_passport_number(self, faker, num_samples):
        faker.add_provider(ItPassportProvider)

        pattern = re.compile(r"^[A-Z]{2}\d{7}$")

        for _ in range(num_samples):
            passport_number = faker.passport_number()
            assert pattern.fullmatch(passport_number)


class TestMkMk:
    """Test mk_MK passport provider methods"""

    def test_passport_number(self, faker, num_samples):
        # Format: 1 uppercase letter + 7 digits
        pattern = re.compile(r"^[A-Z]\d{7}$")
        for _ in range(num_samples):
            passport_number = faker.passport_number()
            assert pattern.fullmatch(passport_number), f"Unexpected format: {passport_number!r}"


class TestPassport:
    """Test passport provider methods"""

    def test_passport_number(self, faker, num_samples):
        for _ in range(num_samples):
            passport_number = faker.passport_number()
            assert isinstance(passport_number, str)



import re

import pytest

from faker.providers.bank import Provider as BankProvider
from faker.providers.bank.az_AZ import Provider as AzAzBankProvider
from faker.providers.bank.cs_CZ import Provider as CsCZBankProvider
from faker.providers.bank.de_CH import Provider as DeChBankProvider
from faker.providers.bank.el_GR import Provider as ElGrBankProvider
from faker.providers.bank.en_GB import Provider as EnGbBankProvider
from faker.providers.bank.en_IE import Provider as EnIeBankProvider
from faker.providers.bank.en_PH import Provider as EnPhBankProvider
from faker.providers.bank.es_AR import Provider as EsArBankProvider
from faker.providers.bank.es_ES import Provider as EsEsBankProvider
from faker.providers.bank.es_MX import Provider as EsMxBankProvider
from faker.providers.bank.es_MX import is_valid_clabe
from faker.providers.bank.fi_FI import Provider as FiFiBankProvider
from faker.providers.bank.fr_FR import Provider as FrFrBankProvider
from faker.providers.bank.mk_MK import Provider as MkMKBankProvider
from faker.providers.bank.nl_BE import Provider as NlBeBankProvider
from faker.providers.bank.no_NO import Provider as NoNoBankProvider
from faker.providers.bank.pl_PL import Provider as PlPlBankProvider
from faker.providers.bank.pt_BR import Provider as PtBrBankProvider
from faker.providers.bank.pt_PT import Provider as PtPtBankProvider
from faker.providers.bank.sk_SK import Provider as SkSKBankProvider
from faker.providers.bank.th_TH import Provider as ThThBankProvider
from faker.providers.bank.tr_TR import Provider as TrTrBankProvider
from faker.providers.bank.uk_UA import Provider as UkUaBankProvider


def is_valid_iban(iban):
    check = iban[4:] + iban[:4]
    check = int("".join(BankProvider.ALPHA.get(c, c) for c in check))
    return check % 97 == 1


def is_valid_aba(aba):
    d = [int(n) for n in aba]
    chkdgt = 3 * (d[0] + d[3] + d[6]) + 7 * (d[1] + d[4] + d[7]) + (d[2] + d[5] + d[8])
    if chkdgt % 10 == 0:
        return True
    return False


class TestAzAz:
    """Test az_AZ bank provider"""

    def test_bban(self, faker, num_samples):
        for _ in range(num_samples):
            assert re.fullmatch(r"[A-Z]{4}\d{20}", faker.bban())

    def test_iban(self, faker, num_samples):
        for _ in range(num_samples):
            iban = faker.iban()
            assert is_valid_iban(iban)
            assert iban[:2] == AzAzBankProvider.country_code
            assert re.fullmatch(r"\d{2}[A-Z]{4}\d{20}", iban[2:])

    def test_bank(self, faker, num_samples):
        for _ in range(num_samples):
            bank = faker.bank()
            assert bank in AzAzBankProvider.banks


class TestBaseBankProvider:
    """Test base bank provider"""

    def test_bank_not_implemented_error(self, faker):
        """Test that bank() raises NotImplementedError when no banks attribute exists.

        Raising NotImplementedError (instead of AttributeError) ensures that
        hasattr(faker, 'bank') correctly returns True (the method exists) while
        still clearly communicating that this locale has not implemented bank
        name generation. Previously AttributeError was raised, which caused
        hasattr() to return False-positive True yet crash on the call.
        See: https://github.com/joke2k/faker/issues/2377
        """

        provider = BankProvider(faker)

        assert not hasattr(provider, "banks")

        with pytest.raises(NotImplementedError):
            provider.bank()


class TestCsCz:
    """Test cs_CZ bank provider"""

    def test_bban(self, faker, num_samples):
        for _ in range(num_samples):
            assert re.fullmatch(r"\d{20}", faker.bban())

    def test_iban(self, faker, num_samples):
        for _ in range(num_samples):
            iban = faker.iban()
            assert is_valid_iban(iban)
            assert iban[:2] == CsCZBankProvider.country_code
            assert re.fullmatch(r"\d{2}\d{20}", iban[2:])


class TestDeCh:
    """Test de_CH bank provider"""

    def test_bban(self, faker, num_samples):
        for _ in range(num_samples):
            assert re.fullmatch(r"\d{17}", faker.bban())

    def test_iban(self, faker, num_samples):
        for _ in range(num_samples):
            iban = faker.iban()
            assert is_valid_iban(iban)
            assert iban[:2] == DeChBankProvider.country_code
            assert re.fullmatch(r"\d{19}", iban[2:])

    def test_bank(self, faker, num_samples):
        for _ in range(num_samples):
            bank = faker.bank()
            assert bank in DeChBankProvider.banks


class TestDeDe:
    """Test de_DE bank provider"""

    def test_swift_use_dataset(self, faker, num_samples):
        regex = re.compile("[A-Z]{6}[A-Z2-9][A-NP-Z0-9]([A-Z0-9]{3})?")
        for _ in range(num_samples):
            code = faker.swift(use_dataset=True)
            assert regex.fullmatch(code) is not None


class TestElGr:
    """Test el_GR bank provider"""

    def test_bank(self, faker, num_samples):
        for _ in range(num_samples):
            bank = faker.bank()
            assert bank in ElGrBankProvider.banks

    def test_bban(self, faker, num_samples):
        for _ in range(num_samples):
            assert re.fullmatch(r"\d{23}", faker.bban())

    def test_iban(self, faker, num_samples):
        for _ in range(num_samples):
            iban = faker.iban()
            assert is_valid_iban(iban)
            assert iban[:2] == ElGrBankProvider.country_code
            assert re.fullmatch(r"\d{2}\d{23}", iban[2:])


class TestEnGb:
    """Test en_GB bank provider"""

    def test_bank(self, faker, num_samples):
        for _ in range(num_samples):
            bank = faker.bank()
            assert isinstance(bank, str)
            assert bank in EnGbBankProvider.banks

    def test_bban(self, faker, num_samples):
        for _ in range(num_samples):
            assert re.fullmatch(r"[A-Z]{4}\d{14}", faker.bban())

    def test_iban(self, faker, num_samples):
        for _ in range(num_samples):
            iban = faker.iban()
            assert is_valid_iban(iban)
            assert iban[:2] == EnGbBankProvider.country_code
            assert re.fullmatch(r"\d{2}[A-Z]{4}\d{14}", iban[2:])


class TestEnIe:
    """Test en_IE bank provider"""

    def test_bban(self, faker, num_samples):
        for _ in range(num_samples):
            assert re.fullmatch(r"\d{23}", faker.bban())

    def test_iban(self, faker, num_samples):
        for _ in range(num_samples):
            iban = faker.iban()
            assert is_valid_iban(iban)
            assert iban[:2] == EnIeBankProvider.country_code
            assert re.fullmatch(r"\d{2}\d{23}", iban[2:])


class TestEnIn:
    """Test en_IN bank provider"""

    def test_bank(self, faker, num_samples):
        for _ in range(num_samples):
            assert re.match(r"\D{7,25}", faker.bank())


class TestEnPh:
    """Test en_PH bank provider"""

    def test_swift(self, faker, num_samples):
        regex = re.compile("[A-Z]{4}PH[A-Z0-9]{2}(?:[A-Z0-9]{3})?")
        for _ in range(num_samples):
            code = faker.swift()
            assert regex.fullmatch(code) is not None

    def test_swift_invalid_length(self, faker):
        faker.swift(length=8)
        faker.swift(length=11)
        with pytest.raises(AssertionError):
            faker.swift(length=5)

    def test_swift8_use_dataset(self, faker, num_samples):
        for _ in range(num_samples):
            code = faker.swift8(use_dataset=True)
            assert len(code) == 8
            assert code[:4] in EnPhBankProvider.swift_bank_codes
            assert code[4:6] == EnPhBankProvider.country_code
            assert code[6:8] in EnPhBankProvider.swift_location_codes

    def test_swift11_use_dataset(self, faker, num_samples):
        for _ in range(num_samples):
            code = faker.swift11(use_dataset=True)
            assert len(code) == 11
            assert code[:4] in EnPhBankProvider.swift_bank_codes
            assert code[4:6] == EnPhBankProvider.country_code
            assert code[6:8] in EnPhBankProvider.swift_location_codes
            assert code[8:11] in EnPhBankProvider.swift_branch_codes

    def test_swift11_is_primary(self, faker, num_samples):
        for _ in range(num_samples):
            code = faker.swift11(primary=True)
            assert len(code) == 11
            assert code[8:11] == "XXX"


class TestEsAr:
    """Test es_AR bank provider"""

    def test_bban(self, faker, num_samples):
        for _ in range(num_samples):
            assert re.fullmatch(r"[A-Z]{4}\d{20}", faker.bban())

    def test_iban(self, faker, num_samples):
        for _ in range(num_samples):
            iban = faker.iban()
            assert is_valid_iban(iban)
            assert iban[:2] == EsArBankProvider.country_code
            assert re.fullmatch(r"\d{2}[A-Z]{4}\d{20}", iban[2:])


class TestEsEs:
    """Test es_ES bank provider"""

    def test_bban(self, faker, num_samples):
        for _ in range(num_samples):
            assert re.fullmatch(r"\d{20}", faker.bban())

    def test_iban(self, faker, num_samples):
        def _ccc_control_digit(number):
            check = sum(int(n) * 2**i for i, n in enumerate(number)) % 11
            return str(check if check < 2 else 11 - check)

        for _ in range(num_samples):
            iban = faker.iban()
            assert is_valid_iban(iban)
            assert iban[:2] == EsEsBankProvider.country_code
            assert re.fullmatch(r"\d{2}\d{20}", iban[2:])
            # the BBAN must carry valid Spanish CCC control digits
            bban = iban[4:]
            bank_branch, control, account = bban[:8], bban[8:10], bban[10:]
            assert control == _ccc_control_digit("00" + bank_branch) + _ccc_control_digit(account)


class TestEsMx:
    """Test es_MX bank provider"""

    def test_bank(self, faker, num_samples):
        for _ in range(num_samples):
            assert faker.bank() in EsMxBankProvider.banks

    @pytest.mark.parametrize(
        "clabe,validity",
        [
            ("002864631170560203", True),
            ("002864631170560202", False),
            ("00286463117056020", False),
            ("0028646311705602030", False),
            ("00286463117056020A", False),
        ],
        ids=[
            "valid",
            "bad_control_digit",
            "too_short",
            "too_long",
            "non_numeric_characters",
        ],
    )
    def test_clabe_validation(self, clabe, validity):
        assert is_valid_clabe(clabe) is validity

    def test_clabe(self, faker, num_samples):
        for _ in range(num_samples):
            clabe = faker.clabe()
            assert is_valid_clabe(clabe)
            assert int(clabe[:3].lstrip("0")) in EsMxBankProvider.bank_codes

    def test_clabe_bank_code(self, faker, num_samples):
        bank_code = 133
        for _ in range(num_samples):
            clabe = faker.clabe(bank_code=bank_code)
            assert is_valid_clabe(clabe)
            assert int(clabe[:3].lstrip("0")) == bank_code


class TestFaIr:
    """Test fa_IR bank provider"""

    def test_bban(self, faker, num_samples):
        for _ in range(num_samples):
            assert re.fullmatch(r"IR\d{24}", faker.bban())

    def test_bank(self, faker, num_samples):
        for _ in range(num_samples):
            assert re.match(r"\D{7,25}", faker.bank())


class TestFiFi:
    """Test fi_FI bank provider"""

    def test_bban(self, faker, num_samples):
        for _ in range(num_samples):
            assert re.fullmatch(r"\d{14}", faker.bban())

    def test_iban(self, faker, num_samples):
        for _ in range(num_samples):
            iban = faker.iban()
            assert is_valid_iban(iban)
            assert iban[:2] == FiFiBankProvider.country_code
            assert re.fullmatch(r"\d{2}\d{14}", iban[2:])


class TestFilPh(TestEnPh):
    """Test fil_PH bank provider"""

    pass


class TestFrCh(TestDeCh):
    """Test fr_CH bank provider"""

    pass


class TestFrFr:
    """Test fr_FR bank provider"""

    def test_bban(self, faker, num_samples):
        for _ in range(num_samples):
            assert re.fullmatch(r"\d{23}", faker.bban())

    def test_iban(self, faker, num_samples):
        for _ in range(num_samples):
            iban = faker.iban()
            assert is_valid_iban(iban)
            assert iban[:2] == FrFrBankProvider.country_code
            assert re.fullmatch(r"\d{2}\d{23}", iban[2:])


class TestItCh(TestDeCh):
    """Test it_CH bank provider"""

    pass


class TestNlBe:
    def test_bban(self, faker, num_samples):
        for _ in range(num_samples):
            bban = faker.bban()
            assert re.fullmatch(r"\d{12}", bban)
            account_number = bban[:-2]
            check_digits = int(bban[-2:])
            assert (int(account_number) % 97) == check_digits or check_digits == 97

    def test_iban(self, faker, num_samples):
        for _ in range(num_samples):
            iban = faker.iban()
            assert iban[:2] == NlBeBankProvider.country_code
            assert re.fullmatch(r"\d{2}\d{12}", iban[2:])
            rearranged_iban = iban[4:] + iban[:4]
            numeric_iban = "".join(str(ord(char) - 55) if char.isalpha() else char for char in rearranged_iban)
            assert int(numeric_iban) % 97 == 1

    def test_iban_stdnum(self, faker, num_samples):
        try:
            from stdnum import iban as iban_validator
        except ImportError:
            pytest.skip("stdnum not available")
        for _ in range(num_samples):
            iban_validator.validate(faker.iban())

    def test_swift8_use_dataset(self, faker, num_samples):
        for _ in range(num_samples):
            code = faker.swift8(use_dataset=True)
            assert len(code) == 8
            assert code[:4] in NlBeBankProvider.swift_bank_codes
            assert code[4:6] == NlBeBankProvider.country_code
            assert code[6:8] in NlBeBankProvider.swift_location_codes

    def test_swift11_use_dataset(self, faker, num_samples):
        for _ in range(num_samples):
            code = faker.swift11(use_dataset=True)
            assert len(code) == 11
            assert code[:4] in NlBeBankProvider.swift_bank_codes
            assert code[4:6] == NlBeBankProvider.country_code
            assert code[6:8] in NlBeBankProvider.swift_location_codes
            assert code[8:11] in NlBeBankProvider.swift_branch_codes


class TestNoNo:
    """Test no_NO bank provider"""

    def test_aba(self, faker, num_samples):
        for _ in range(num_samples):
            aba = faker.aba()
            assert len(aba) == 9
            assert is_valid_aba(aba)

    def test_bban(self, faker, num_samples):
        for _ in range(num_samples):
            assert re.fullmatch(r"\d{11}", faker.bban())

    def test_iban(self, faker, num_samples):
        for _ in range(num_samples):
            iban = faker.iban()
            assert is_valid_iban(iban)
            assert iban[:2] == NoNoBankProvider.country_code
            assert re.fullmatch(r"\d{2}\d{11}", iban[2:])


class TestPlPl:
    """Test pl_PL bank provider"""

    def test_bban(self, faker, num_samples):
        for _ in range(num_samples):
            assert re.fullmatch(r"\d{24}", faker.bban())

    def test_iban(self, faker, num_samples):
        for _ in range(num_samples):
            iban = faker.iban()
            assert is_valid_iban(iban)
            assert iban[:2] == PlPlBankProvider.country_code
            assert re.fullmatch(r"\d{2}\d{24}", iban[2:])


class TestPtBr:
    """Test pt_BR bank provider"""

    def test_bban(self, faker, num_samples):
        for _ in range(num_samples):
            assert re.fullmatch(r"\d{23}[A-Z]{2}", faker.bban())

    def test_iban(self, faker, num_samples):
        for _ in range(num_samples):
            iban = faker.iban()
            assert is_valid_iban(iban)
            assert iban[:2] == PtBrBankProvider.country_code
            assert re.fullmatch(r"\d{2}\d{23}[A-Z]{2}", iban[2:])


class TestPtPt:
    """Test pt_PT bank provider"""

    def test_bban(self, faker, num_samples):
        for _ in range(num_samples):
            assert re.fullmatch(r"\d{21}", faker.bban())

    def test_iban(self, faker, num_samples):
        for _ in range(num_samples):
            iban = faker.iban()
            assert is_valid_iban(iban)
            assert iban[:2] == PtPtBankProvider.country_code
            assert re.fullmatch(r"\d{2}\d{21}", iban[2:])


class TestRuRu:
    """Test ru_RU bank provider"""

    def test_bic(self, faker, num_samples):
        for _ in range(num_samples):
            assert re.match(r"04\d{7,9}", faker.bic())

    def test_correspondent_account(self, faker, num_samples):
        for _ in range(num_samples):
            assert re.match(r"301\d{17}", faker.correspondent_account())

    def test_checking_account(self, faker, num_samples):
        for _ in range(num_samples):
            assert re.match(r"\d{3}0\d{16}", faker.checking_account())

    def test_bank(self, faker, num_samples):
        for _ in range(num_samples):
            assert re.match(r"\D{3,41}", faker.bank())


class TestSkSk:
    """Test sk_SK bank provider"""

    def test_bban(self, faker, num_samples):
        for _ in range(num_samples):
            assert re.fullmatch(r"\d{20}", faker.bban())

    def test_iban(self, faker, num_samples):
        for _ in range(num_samples):
            iban = faker.iban()
            assert is_valid_iban(iban)
            assert iban[:2] == SkSKBankProvider.country_code
            assert re.fullmatch(r"\d{2}\d{20}", iban[2:])


class TestThTh:
    """Test th_TH bank provider"""

    def test_bban(self, faker, num_samples):
        for _ in range(num_samples):
            assert re.fullmatch(r"\d{10}", faker.bban())

    def test_iban(self, faker, num_samples):
        for _ in range(num_samples):
            iban = faker.iban()
            assert is_valid_iban(iban)
            assert iban[:2] == ThThBankProvider.country_code
            assert re.fullmatch(r"\d{2}\d{10}", iban[2:])


class TestTlPh(TestEnPh):
    """Test tl_PH bank provider"""

    pass


class TestTrTr:
    """Test tr_TR bank provider"""

    def test_bban(self, faker, num_samples):
        for _ in range(num_samples):
            assert re.fullmatch(r"\d{22}", faker.bban())

    def test_iban(self, faker, num_samples):
        for _ in range(num_samples):
            iban = faker.iban()
            assert is_valid_iban(iban)
            assert iban[:2] == TrTrBankProvider.country_code
            assert re.fullmatch(r"\d{2}\d{22}", iban[2:])


class TestUkUa:
    """Test uk_UA bank provider"""

    def test_bban(self, faker, num_samples):
        for _ in range(num_samples):
            assert re.fullmatch(r"\d{27}", faker.bban())

    def test_iban(self, faker, num_samples):
        for _ in range(num_samples):
            iban = faker.iban()
            assert is_valid_iban(iban)
            assert iban[:2] == UkUaBankProvider.country_code
            assert re.fullmatch(r"\d{2}\d{27}", iban[2:])


class TestZhCn:
    """Test zh_CN bank provider"""

    def test_bank(self, faker, num_samples):
        for _ in range(num_samples):
            assert re.match(r"[\u4e00-\u9fa5]{2,20}", faker.bank())


class TestMkMk:
    """Test mk_MK bank provider methods"""

    def test_bank(self, faker, num_samples):
        for _ in range(num_samples):
            bank = faker.bank()
            assert isinstance(bank, str)
            assert bank in MkMKBankProvider.banks

    def test_iban(self, faker, num_samples):
        for _ in range(num_samples):
            iban = faker.iban()
            assert isinstance(iban, str)
            assert iban.startswith("MK")
            assert len(iban) == 21  # MK(2) + check(2) + bban(17)



import pytest

from faker import Faker
from faker.exceptions import UniquenessException


class TestSelectiveUniqueness:
    def setup_method(self):
        self.fake = Faker()
        self.fake.unique.clear()

    def test_exclude_types_excludes_bools(self):
        """Test that excluded types can return duplicates."""
        proxy = self.fake.unique.exclude_types([bool])

        # Should be able to call pybool many times without exhaustion
        # (only 2 possible values: True/False)
        for _ in range(10):
            val = proxy.pybool()
            assert isinstance(val, bool)

        # Should not raise UniquenessException

    def test_exclude_types_still_enforces_other_types(self):
        """Test that non-excluded types still enforce uniqueness."""
        proxy = self.fake.unique.exclude_types([bool])

        # Names should still be unique
        names = [proxy.first_name() for _ in range(5)]
        assert len(set(names)) == 5, "Names should all be unique"

    def test_exclude_types_with_limited_values(self):
        """Test that excluding types prevents exhaustion."""
        proxy = self.fake.unique.exclude_types([bool])

        # This should work fine even though there are only 2 boolean values
        bools = [proxy.pybool() for _ in range(100)]
        assert all(isinstance(b, bool) for b in bools)

    def test_without_exclusion_bools_exhaust(self):
        """Test that without exclusion, bools still exhaust as before."""
        self.fake.unique.clear()

        # Should be able to get True and False
        b1 = self.fake.unique.pybool()
        b2 = self.fake.unique.pybool()
        assert b1 != b2  # One True, one False

        # Third call should raise
        with pytest.raises(UniquenessException):
            self.fake.unique.pybool()

    def test_exclude_types_chainable(self):
        """Test that exclude_types returns a new proxy that can be used."""
        proxy1 = self.fake.unique.exclude_types([bool])
        proxy2 = self.fake.unique.exclude_types([int])

        # Both should be independent
        assert proxy1 is not proxy2
        assert proxy1._excluded_types == (bool,)
        assert proxy2._excluded_types == (int,)

    def test_exclude_multiple_types(self):
        """Test excluding multiple types at once."""
        proxy = self.fake.unique.exclude_types([bool, int])

        # Bools should not enforce uniqueness
        for _ in range(10):
            proxy.pybool()

        # Ints should not enforce uniqueness
        for _ in range(10):
            proxy.pyint(min_value=0, max_value=1)  # Only 2 values

    def test_exclude_types_shares_seen_dict(self):
        """Test that excluded proxy shares the seen dictionary."""
        self.fake.unique.clear()

        # Get a unique name through original proxy
        name1 = self.fake.unique.first_name()

        # Create excluded proxy and try to get same name
        proxy = self.fake.unique.exclude_types([bool])
        name2 = proxy.first_name()

        # Should not be the same (shares seen dict)
        assert name1 != name2

    def test_exclude_types_preserves_across_locales(self):
        """Test that exclusions work with locale proxying."""
        fake_multi = Faker(["en_US", "fr_FR"])
        proxy = fake_multi.unique.exclude_types([bool])

        # Should work with locale selection
        for _ in range(10):
            proxy["en_US"].pybool()



from faker.utils.text import slugify


def test_slugify_converts_to_lowercase_and_hyphens():
    """Check if uppercase letters are converted to lowercase and spaces to hyphens"""
    input_text = "My New Function"
    expected_output = "my-new-function"

    result = slugify(input_text)

    assert result == expected_output


def test_slugify_with_special_characters():
    """Check if special characters and accented letters are handled correctly"""
    input_text = "Zażółć Gęślą Jaźń! @2026"
    expected_output = "zazoc-gesla-jazn-2026"

    result = slugify(input_text)

    assert result == expected_output


def test_slugify_empty_string():
    """Check how the function handles an empty string"""
    input_text = ""
    expected_output = ""

    result = slugify(input_text)

    assert result == expected_output


def test_slugify_with_multiple_spaces_and_hyphens():
    """Check if the function cleans up multiple spaces and hyphens"""
    input_text = "many    spaces --- and --- hyphens"
    expected_output = "many-spaces-and-hyphens"

    result = slugify(input_text)

    assert result == expected_output



from .. import Provider as BaseProvider

# List updated from CBO 2002
# A Classificação Brasileira de Ocupações - CBO, instituída por portaria ministerial
# nº. 397, de 9 de outubro de 2002, tem por finalidade a identificação das ocupações
# no mercado de trabalho, para fins classificatórios junto aos registros
# administrativos e domiciliares.
#
# https://www.gov.br/trabalho-e-emprego/pt-br/assuntos/cbo


class Provider(BaseProvider):
    jobs = [
        "Oficial general da aeronáutica",
        "Oficial general do exército",
        "Oficial general da marinha",
        "Oficial da aeronáutica",
        "Oficial do exército",
        "Oficial da marinha",
        "Praça da aeronáutica",
        "Praça do exército",
        "Praça da marinha",
        "Coronel da polícia militar",
        "Tenente-coronel da polícia militar",
        "Major da polícia militar",
        "Capitão da polícia militar",
        "Primeiro tenente de polícia militar",
        "Segundo tenente de polícia militar",
        "Subtenente da policia militar",
        "Sargento da policia militar",
        "Cabo da polícia militar",
        "Soldado da polícia militar",
        "Coronel bombeiro militar",
        "Major bombeiro militar",
        "Tenente-coronel bombeiro militar",
        "Capitão bombeiro militar",
        "Tenente do corpo de bombeiros militar",
        "Subtenente bombeiro militar",
        "Sargento bombeiro militar",
        "Cabo bombeiro militar",
        "Soldado bombeiro militar",
        "Senador",
        "Deputado federal",
        "Deputado estadual e distrital",
        "Vereador",
        "Presidente da república",
        "Vice-presidente da república",
        "Ministro de estado",
        "Secretário - executivo",
        "Membro superior do poder executivo",
        "Governador de estado",
        "Governador do distrito federal",
        "Vice-governador de estado",
        "Vice-governador do distrito federal",
        "Prefeito",
        "Vice-prefeito",
        "Ministro do supremo tribunal federal",
        "Ministro do superior tribunal de justiça",
        "Ministro do  superior tribunal militar",
        "Ministro do  superior tribunal do trabalho",
        "Juiz de direito",
        "Juiz federal",
        "Juiz auditor federal - justiça militar",
        "Juiz auditor estadual - justiça militar",
        "Juiz do trabalho",
        "Dirigente do serviço público federal",
        "Dirigente do serviço público estadual e distrital",
        "Dirigente do serviço público municipal",
        "Especialista de políticas públicas e gestão governamental - eppgg",
        "Analista de planejamento e orçamento - apo",
        "Cacique",
        "Líder de comunidade caiçara",
        "Membro de liderança quilombola",
        "Dirigente de partido político",
        "Dirigente de entidade de trabalhadores",
        "Dirigente de entidade patronal",
        "Dirigente e administrador de organização religiosa",
        "Dirigente e administrador de organização da sociedade civil sem fins lucrativos",
        "Diretor de planejamento estratégico",
        "Diretor geral de empresa e organizações (exceto de interesse público)",
        "Diretor de produção e operações em empresa agropecuária",
        "Diretor de produção e operações em empresa aqüícola",
        "Diretor de produção e operações em empresa florestal",
        "Diretor de produção e operações em empresa pesqueira",
        "Diretor de produção e operações da indústria de transformação, extração mineral e utilidades",
        "Diretor de operações de obras pública e civil",
        "Diretor de operações comerciais (comércio atacadista e varejista)",
        "Diretor de  produção e operações de alimentação",
        "Diretor de  produção e operações de hotel",
        "Diretor de  produção e operações de turismo",
        "Turismólogo",
        "Diretor de operações de correios",
        "Diretor de operações de serviços de armazenamento",
        "Diretor de operações de serviços de telecomunicações",
        "Diretor de operações de serviços de transporte",
        "Diretor comercial em operações de intermediação financeira",
        "Diretor de produtos bancários",
        "Diretor de crédito rural",
        "Diretor de câmbio e comércio exterior",
        "Diretor de compliance",
        "Diretor de crédito (exceto crédito imobiliário)",
        "Diretor de crédito imobiliário",
        "Diretor de leasing",
        "Diretor de mercado de capitais",
        "Diretor de recuperação de créditos em operações de intermediação financeira",
        "Diretor de riscos de mercado",
        "Diretor administrativo",
        "Diretor administrativo e financeiro",
        "Diretor financeiro",
        "Diretor de recursos humanos",
        "Diretor de relações de trabalho",
        "Diretor comercial",
        "Diretor de marketing",
        "Diretor de suprimentos",
        "Diretor de suprimentos no serviço público",
        "Diretor de tecnologia da informação",
        "Diretor de pesquisa e desenvolvimento (p&d)",
        "Diretor de manutenção",
        "Diretor de serviços culturais",
        "Diretor de serviços sociais",
        "Gerente de serviços culturais",
        "Gerente de serviços sociais",
        "Diretor de serviços de saúde",
        "Gerente de serviços de saúde",
        "Tecnólogo em gestão hospitalar",
        "Gerontólogo",
        "Sanitarista",
        "Diretor de instituição educacional da área privada",
        "Diretor de instituição educacional pública",
        "Gerente de instituição educacional da área privada",
        "Gerente de serviços educacionais da área pública",
        "Gerente de produção e operações  aqüícolas",
        "Gerente de produção e operações  florestais",
        "Gerente de produção e operações agropecuárias",
        "Gerente de produção e operações pesqueiras",
        "Gerente de produção e operações",
        "Gerente de produção e operações da construção civil e obras públicas",
        "Comerciante atacadista",
        "Comerciante varejista",
        "Gerente de loja e supermercado",
        "Gerente de operações de serviços de assistência técnica",
        "Gerente de hotel",
        "Gerente de restaurante",
        "Gerente de bar",
        "Gerente de pensão",
        "Gerente de turismo",
        "Gerente de operações de transportes",
        "Gerente de operações de correios e telecomunicações",
        "Gerente de logística (armazenagem e distribuição)",
        "Gerente de produtos bancários",
        "Gerente de agência",
        "Gerente de câmbio e comércio exterior",
        "Gerente de crédito e cobrança",
        "Gerente de crédito imobiliário",
        "Gerente de crédito rural",
        "Gerente de recuperação de crédito",
        "Gerente de administração em aeroportos",
        "Gerente de empresa aérea e empresa de serviços auxiliares ao transporte aéreo (esata) em aeroportos",
        "Gerente de operações em aeroportos",
        "Gerente de operações de cargas",
        "Gerente de segurança da aviação civil",
        "Gerente de segurança operacional (aviação civil)",
        "Gerente administrativo",
        "Gerente de riscos",
        "Gerente financeiro",
        "Tecnólogo em gestão administrativo- financeira",
        "Analista de compliance",
        "Analista de riscos",
        "Oficial de proteção de dados pessoais (dpo)",
        "Gerente de facility management",
        "Gerente de recursos humanos",
        "Gerente de departamento pessoal",
        "Gerente comercial",
        "Gerente de comunicação",
        "Gerente de marketing",
        "Gerente de vendas",
        "Relações públicas",
        "Analista de negócios",
        "Analista de pesquisa de mercado",
        "Ouvidor",
        "Profissional de relações institucionais e governamentais",
        "Profissonal de relações internacionais",
        "Analista de e-commerce",
        "Gerente de compras",
        "Gerente de suprimentos",
        "Gerente de almoxarifado",
        "Gerente de infraestrutura de tecnologia da informação",
        "Gerente de desenvolvimento de sistemas",
        "Gerente de operação de tecnologia da informação",
        "Gerente de projetos de tecnologia da informação",
        "Gerente de segurança da informação",
        "Gerente de suporte técnico de tecnologia da informação",
        "Tecnólogo em gestão da tecnologia da informação",
        "Gerente de pesquisa e desenvolvimento (p&d)",
        "Especialista em desenvolvimento de cigarros",
        "Gerente de projetos e serviços de manutenção",
        "Tecnólogo em sistemas biomédicos",
        "Bioengenheiro",
        "Biotecnologista",
        "Geneticista",
        "Pesquisador em metrologia",
        "Especialista em calibrações metrológicas",
        "Especialista em ensaios metrológicos",
        "Especialista em instrumentação metrológica",
        "Especialista em materiais de referência metrológica",
        "Engenheiro mecatrônico",
        "Engenheiro de controle e automação",
        "Tecnólogo em mecatrônica",
        "Tecnólogo em automação industrial",
        "Pesquisador em biologia ambiental",
        "Pesquisador em biologia animal",
        "Pesquisador em biologia de microorganismos e parasitas",
        "Pesquisador em biologia humana",
        "Pesquisador em biologia vegetal",
        "Pesquisador em ciências da computação e informática",
        "Pesquisador em ciências da terra e meio ambiente",
        "Pesquisador em física",
        "Pesquisador em matemática",
        "Pesquisador em química",
        "Pesquisador de engenharia civil",
        "Pesquisador de engenharia e tecnologia (outras áreas da engenharia)",
        "Pesquisador de engenharia elétrica e eletrônica",
        "Pesquisador de engenharia mecânica",
        "Pesquisador de engenharia metalúrgica, de minas e de materiais",
        "Pesquisador de engenharia química",
        "Pesquisador de clínica médica",
        "Pesquisador de medicina básica",
        "Pesquisador em medicina veterinária",
        "Pesquisador em saúde coletiva",
        "Pesquisador em ciências agronômicas",
        "Pesquisador em ciências da pesca e aqüicultura",
        "Pesquisador em ciências da zootecnia",
        "Pesquisador em ciências florestais",
        "Pesquisador em ciências sociais e humanas",
        "Pesquisador em economia",
        "Pesquisador em ciências da educação",
        "Pesquisador em história",
        "Pesquisador em psicologia",
        "Perito criminal",
        "Perito judicial",
        "Atuário",
        "Especialista em pesquisa operacional",
        "Matemático",
        "Matemático aplicado",
        "Estatístico",
        "Estatístico (estatística aplicada)",
        "Estatístico teórico",
        "Cientista de dados",
        "Engenheiro de aplicativos em computação",
        "Engenheiro de equipamentos em computação",
        "Engenheiros de sistemas operacionais em computação",
        "Administrador de banco de dados",
        "Administrador de redes",
        "Administrador de sistemas operacionais",
        "Administrador em segurança da informação",
        "Analista de desenvolvimento de sistemas",
        "Analista de redes e de comunicação de dados",
        "Analista de sistemas de automação",
        "Analista de suporte computacional",
        "Arquiteto de soluções de tecnologia da informação",
        "Analista de testes de tecnologia da informação",
        "Físico",
        "Físico (acústica)",
        "Físico (atômica e molecular)",
        "Físico (cosmologia)",
        "Físico (estatística e matemática)",
        "Físico (fluidos)",
        "Físico (instrumentação)",
        "Físico (matéria condensada)",
        "Físico (materiais)",
        "Físico (medicina)",
        "Físico (nuclear e reatores)",
        "Físico (óptica)",
        "Físico (partículas e campos)",
        "Físico (plasma)",
        "Físico (térmica)",
        "Químico",
        "Químico industrial",
        "Tecnólogo em processos químicos",
        "Astrônomo",
        "Geofísico espacial",
        "Meteorologista",
        "Geólogo",
        "Geólogo de engenharia",
        "Geofísico",
        "Geoquímico",
        "Hidrogeólogo",
        "Paleontólogo",
        "Petrógrafo",
        "Oceanógrafo",
        "Engenheiro ambiental",
        "Tecnólogo em meio ambiente",
        "Arquiteto de edificações",
        "Arquiteto de interiores",
        "Arquiteto de patrimônio",
        "Arquiteto paisagista",
        "Arquiteto urbanista",
        "Urbanista",
        "Engenheiro civil",
        "Engenheiro civil (aeroportos)",
        "Engenheiro civil (edificações)",
        "Engenheiro civil (estruturas metálicas)",
        "Engenheiro civil (ferrovias e metrovias)",
        "Engenheiro civil (geotécnia)",
        "Engenheiro civil (hidrologia)",
        "Engenheiro civil (hidráulica)",
        "Engenheiro civil (pontes e viadutos)",
        "Engenheiro civil (portos e vias navegáveis)",
        "Engenheiro civil (rodovias)",
        "Engenheiro civil (saneamento)",
        "Engenheiro civil (túneis)",
        "Engenheiro civil (transportes e trânsito)",
        "Tecnólogo em construção civil",
        "Engenheiro eletricista",
        "Engenheiro eletrônico",
        "Engenheiro eletricista de manutenção",
        "Engenheiro eletricista de projetos",
        "Engenheiro eletrônico de manutenção",
        "Engenheiro eletrônico de projetos",
        "Engenheiro de manutenção de telecomunicações",
        "Engenheiro de telecomunicações",
        "Engenheiro projetista de telecomunicações",
        "Engenheiro de redes de comunicação",
        "Tecnólogo em eletricidade",
        "Tecnólogo em eletrônica",
        "Tecnólogo em telecomunicações",
        "Engenheiro de energia",
        "Engenheiro biomédico",
        "Engenheiro mecânico",
        "Engenheiro mecânico automotivo",
        "Engenheiro mecânico (energia nuclear)",
        "Engenheiro mecânico industrial",
        "Engenheiro aeronáutico",
        "Engenheiro naval",
        "Tecnólogo em fabricação mecânica",
        "Engenheiro químico",
        "Engenheiro químico (indústria química)",
        "Engenheiro químico (mineração, metalurgia, siderurgia, cimenteira e cerâmica)",
        "Engenheiro químico (papel e celulose)",
        "Engenheiro químico (petróleo e borracha)",
        "Engenheiro químico (utilidades e meio ambiente)",
        "Tecnólogo em produção sulcroalcooleira",
        "Engenheiro têxtil",
        "Engenheiro de materiais",
        "Engenheiro metalurgista",
        "Tecnólogo em metalurgia",
        "Engenheiro de minas",
        "Engenheiro de minas (beneficiamento)",
        "Engenheiro de minas (lavra a céu aberto)",
        "Engenheiro de minas (lavra subterrânea)",
        "Engenheiro de minas (pesquisa mineral)",
        "Engenheiro de minas (planejamento)",
        "Engenheiro de minas (processo)",
        "Engenheiro de minas (projeto)",
        "Tecnólogo em petróleo e gás",
        "Tecnólogo em rochas ornamentais",
        "Engenheiro agrimensor",
        "Engenheiro cartógrafo",
        "Engenheiro de produção",
        "Engenheiro de controle de qualidade",
        "Engenheiro de segurança do trabalho",
        "Engenheiro de riscos",
        "Engenheiro de tempos e movimentos",
        "Tecnólogo em produção industrial",
        "Tecnólogo em segurança do trabalho",
        "Higienista ocupacional",
        "Engenheiro de logistica",
        "Agente de manobra e docagem",
        "Capitão de manobra da marinha mercante",
        "Comandante da marinha mercante",
        "Coordenador de operações de combate à poluição no meio aquaviário",
        "Imediato da marinha mercante",
        "Inspetor de terminal",
        "Inspetor naval",
        "Oficial de quarto de navegação da marinha mercante",
        "Prático de portos da marinha mercante",
        "Vistoriador naval",
        "Oficial superior de máquinas da marinha mercante",
        "Primeiro oficial de máquinas da marinha mercante",
        "Segundo oficial de máquinas da marinha mercante",
        "Superintendente técnico no transporte aquaviário",
        "Piloto de aeronaves",
        "Piloto de ensaios em vôo",
        "Instrutor de vôo",
        "Biólogo",
        "Biomédico",
        "Engenheiro agrícola",
        "Engenheiro agrônomo",
        "Engenheiro de pesca",
        "Engenheiro florestal",
        "Tecnólogo em agronegócio",
        "Engenheiro de alimentos",
        "Tecnólogo em alimentos",
        "Cirurgião dentista - auditor",
        "Cirurgião dentista - clínico geral",
        "Cirurgião dentista - endodontista",
        "Cirurgião dentista - epidemiologista",
        "Cirurgião dentista - estomatologista",
        "Cirurgião dentista - implantodontista",
        "Cirurgião dentista - odontogeriatra",
        "Cirurgião dentista - odontologista legal",
        "Cirurgião dentista - odontopediatra",
        "Cirurgião dentista - ortopedista e ortodontista",
        "Cirurgião dentista - patologista bucal",
        "Cirurgião dentista - periodontista",
        "Cirurgião dentista - protesiólogo bucomaxilofacial",
        "Cirurgião dentista - protesista",
        "Cirurgião dentista - radiologista",
        "Cirurgião dentista - reabilitador oral",
        "Cirurgião dentista - traumatologista bucomaxilofacial",
        "Cirurgião dentista de saúde coletiva",
        "Cirurgião dentista - odontologia do trabalho",
        "Cirurgião dentista - dentística",
        "Cirurgião dentista - disfunção temporomandibular e dor orofacial",
        "Cirurgião dentista - odontologia para pacientes com necessidades especiais",
        "Cirurgião-dentista da estratégia de saúde da família",
        "Médico veterinário",
        "Zootecnista",
        "Farmacêutico",
        "Farmacêutico analista clínico",
        "Farmacêutico de alimentos",
        "Farmacêutico práticas integrativas e complementares",
        "Farmacêutico em saúde pública",
        "Farmacêutico industrial",
        "Farmacêutico toxicologista",
        "Farmacêutico hospitalar e clínico",
        "Enfermeiro",
        "Enfermeiro auditor",
        "Enfermeiro de bordo",
        "Enfermeiro de centro cirúrgico",
        "Enfermeiro de terapia intensiva",
        "Enfermeiro do trabalho",
        "Enfermeiro nefrologista",
        "Enfermeiro neonatologista",
        "Enfermeiro obstétrico",
        "Enfermeiro psiquiátrico",
        "Enfermeiro puericultor e pediátrico",
        "Enfermeiro sanitarista",
        "Enfermeiro da estratégia de saúde da família",
        "Perfusionista",
        "Obstetriz",
        "Enfermeiro estomaterapeuta",
        "Enfermeiro forense",
        "Fisioterapeuta geral",
        "Fisioterapeuta respiratória",
        "Fisioterapeuta neurofuncional",
        "Fisioterapeuta traumato-ortopédica funcional",
        "Fisioterapeuta osteopata",
        "Fisioterapeuta quiropraxista",
        "Fisioterapeuta acupunturista",
        "Fisioterapeuta esportivo",
        "Fisioterapeuta  do trabalho",
        "Dietista",
        "Nutricionista",
        "Fonoaudiólogo geral",
        "Fonoaudiólogo educacional",
        "Fonoaudiólogo em audiologia",
        "Fonoaudiólogo em disfagia",
        "Fonoaudiólogo em linguagem",
        "Fonoaudiólogo em motricidade orofacial",
        "Fonoaudiólogo em saúde coletiva",
        "Fonoaudiólogo em voz",
        "Terapeuta ocupacional",
        "Ortoptista",
        "Psicomotricista",
        "Avaliador físico",
        "Ludomotricista",
        "Preparador de atleta",
        "Preparador físico",
        "Técnico de desporto individual e coletivo (exceto futebol)",
        "Técnico de laboratório e fiscalização desportiva",
        "Treinador profissional de futebol",
        "Profissional de educação física na saúde",
        "Médico infectologista",
        "Médico acupunturista",
        "Médico legista",
        "Médico nefrologista",
        "Médico alergista e imunologista",
        "Médico neurologista",
        "Médico angiologista",
        "Médico nutrologista",
        "Médico cardiologista",
        "Médico oncologista clínico",
        "Médico cancerologista pediátrico",
        "Médico pediatra",
        "Médico clínico",
        "Médico pneumologista",
        "Médico de família e comunidade",
        "Médico psiquiatra",
        "Médico dermatologista",
        "Médico reumatologista",
        "Médico sanitarista",
        "Médico do trabalho",
        "Médico da estratégia de saúde da família",
        "Médico em medicina de tráfego",
        "Médico anatomopatologista",
        "Médico em medicina intensiva",
        "Médico anestesiologista",
        "Médico antroposófico",
        "Médico endocrinologista e metabologista",
        "Médico fisiatra",
        "Médico gastroenterologista",
        "Médico generalista",
        "Médico geneticista",
        "Médico geriatra",
        "Médico hematologista",
        "Médico homeopata",
        "Médico em cirurgia vascular",
        "Médico cirurgião cardiovascular",
        "Médico cirurgião de cabeça e pescoço",
        "Médico cirurgião do aparelho digestivo",
        "Médico cirurgião geral",
        "Médico cirurgião pediátrico",
        "Médico cirurgião plástico",
        "Médico cirurgião torácico",
        "Médico ginecologista e obstetra",
        "Médico mastologista",
        "Médico neurocirurgião",
        "Médico oftalmologista",
        "Médico ortopedista e traumatologista",
        "Médico otorrinolaringologista",
        "Médico coloproctologista",
        "Médico urologista",
        "Médico cancerologista cirurgíco",
        "Médico cirurgião da mão",
        "Médico citopatologista",
        "Médico em endoscopia",
        "Médico em medicina nuclear",
        "Médico em radiologia e diagnóstico por imagem",
        "Médico patologista",
        "Médico radioterapeuta",
        "Médico patologista clínico / medicina laboratorial",
        "Médico hemoterapeuta",
        "Médico hiperbarista",
        "Médico neurofisiologista clínico",
        "Médico radiologista intervencionista",
        "Quiropraxista",
        "Osteopata",
        "Musicoterapeuta",
        "Arteterapeuta",
        "Equoterapeuta",
        "Naturólogo",
        "Professor de nível superior na educação infantil (quatro a seis anos)",
        "Professor de nível superior na educação infantil (zero a três anos)",
        "Professor da  educação de jovens e adultos do ensino fundamental (primeira a quarta série)",
        "Professor de nível superior do ensino fundamental (primeira a quarta série)",
        "Professor de ciências exatas e naturais do ensino fundamental",
        "Professor de educação artística do ensino fundamental",
        "Professor de educação física do ensino fundamental",
        "Professor de geografia do ensino fundamental",
        "Professor de história do ensino fundamental",
        "Professor de língua estrangeira moderna do ensino fundamental",
        "Professor de língua portuguesa do ensino fundamental",
        "Professor de matemática do ensino fundamental",
        "Professor de artes no ensino médio",
        "Professor de biologia no ensino médio",
        "Professor de disciplinas pedagógicas no ensino médio",
        "Professor de educação física no ensino médio",
        "Professor de filosofia no ensino médio",
        "Professor de física no ensino médio",
        "Professor de geografia no ensino médio",
        "Professor de história no ensino médio",
        "Professor de língua e literatura brasileira no ensino médio",
        "Professor de língua estrangeira moderna no ensino médio",
        "Professor de matemática no ensino médio",
        "Professor de psicologia no ensino médio",
        "Professor de química no ensino médio",
        "Professor de sociologia no ensino médio",
        "Professor da área de meio ambiente",
        "Professor de desenho técnico",
        "Professor de técnicas agrícolas",
        "Professor de técnicas comerciais e secretariais",
        "Professor de técnicas de enfermagem",
        "Professor de técnicas industriais",
        "Professor de tecnologia e cálculo técnico",
        "Instrutor de aprendizagem e treinamento agropecuário",
        "Instrutor de aprendizagem e treinamento industrial",
        "Instrutor de aprendizagem e treinamento comercial",
        "Professor instrutor de ensino e aprendizagem agroflorestal",
        "Professor instrutor de ensino e aprendizagem em serviços",
        "Professor de matemática aplicada (no ensino superior)",
        "Professor de matemática pura (no ensino superior)",
        "Professor de estatística (no ensino superior)",
        "Professor de computação (no ensino superior)",
        "Professor de pesquisa operacional (no ensino superior)",
        "Professor de física (ensino superior)",
        "Professor de química (ensino superior)",
        "Professor de astronomia (ensino superior)",
        "Professor de arquitetura",
        "Professor de engenharia",
        "Professor de geofísica",
        "Professor de geologia",
        "Professor de ciências biológicas do ensino superior",
        "Professor de educação física no ensino superior",
        "Professor de enfermagem do ensino superior",
        "Professor de farmácia e bioquímica",
        "Professor de fisioterapia",
        "Professor de fonoaudiologia",
        "Professor de medicina",
        "Professor de medicina veterinária",
        "Professor de nutrição",
        "Professor de odontologia",
        "Professor de terapia ocupacional",
        "Professor de zootecnia do ensino superior",
        "Professor de ensino superior na área de didática",
        "Professor de ensino superior na área de orientação educacional",
        "Professor de ensino superior na área de pesquisa educacional",
        "Professor de ensino superior na área de prática de ensino",
        "Professor de língua alemã",
        "Professor de língua italiana",
        "Professor de língua francesa",
        "Professor de língua inglesa",
        "Professor de língua espanhola",
        "Professor de língua portuguesa",
        "Professor de literatura brasileira",
        "Professor de literatura portuguesa",
        "Professor de literatura alemã",
        "Professor de literatura comparada",
        "Professor de literatura espanhola",
        "Professor de literatura francesa",
        "Professor de literatura inglesa",
        "Professor de literatura italiana",
        "Professor de literatura de línguas estrangeiras modernas",
        "Professor de outras línguas e literaturas",
        "Professor de línguas estrangeiras modernas",
        "Professor de lingüística e lingüística aplicada",
        "Professor de filologia e crítica textual",
        "Professor de semiótica",
        "Professor de teoria da literatura",
        "Professor de língua brasileira de sinais (libras)",
        "Professor de antropologia do ensino superior",
        "Professor de arquivologia do ensino superior",
        "Professor de biblioteconomia do ensino superior",
        "Professor de ciência política do ensino superior",
        "Professor de comunicação social do ensino superior",
        "Professor de direito do ensino superior",
        "Professor de filosofia do ensino superior",
        "Professor de geografia do ensino superior",
        "Professor de história do ensino superior",
        "Professor de jornalismo",
        "Professor de museologia do ensino superior",
        "Professor de psicologia do ensino superior",
        "Professor de serviço social do ensino superior",
        "Professor de sociologia do ensino superior",
        "Professor de economia",
        "Professor de administração",
        "Professor de contabilidade",
        "Professor de artes do espetáculo no ensino superior",
        "Professor de artes visuais no ensino superior (artes plásticas e multimídia)",
        "Professor de música no ensino superior",
        "Professor de alunos com deficiência auditiva e surdos",
        "Professor de alunos com deficiência física",
        "Professor de alunos com deficiência mental",
        "Professor de alunos com deficiência múltipla",
        "Professor de alunos com deficiência visual",
        "Coordenador pedagógico",
        "Orientador educacional",
        "Pedagogo",
        "Professor de técnicas e recursos audiovisuais",
        "Psicopedagogo",
        "Supervisor de ensino",
        "Designer educacional",
        "Neuropsicopedagogo clinico",
        "Neuropsicopedagogo institucional",
        "Advogado",
        "Advogado de empresa",
        "Advogado (direito civil)",
        "Advogado (direito público)",
        "Advogado (direito penal)",
        "Advogado (áreas especiais)",
        "Advogado (direito do trabalho)",
        "Consultor jurídico",
        "Advogado da união",
        "Procurador autárquico",
        "Procurador da fazenda nacional",
        "Procurador do estado",
        "Procurador do município",
        "Procurador federal",
        "Procurador fundacional",
        "Oficial de registro de contratos marítimos",
        "Oficial do registro civil de pessoas jurídicas",
        "Oficial do registro civil de pessoas naturais",
        "Oficial do registro de distribuições",
        "Oficial do registro de imóveis",
        "Oficial do registro de títulos e documentos",
        "Tabelião de notas",
        "Tabelião de protestos",
        "Conselheiro julgador",
        "Procurador da república",
        "Procurador de justiça",
        "Procurador de justiça militar",
        "Procurador do trabalho",
        "Procurador regional da república",
        "Procurador regional do trabalho",
        "Promotor de justiça",
        "Subprocurador de justiça militar",
        "Subprocurador-geral da república",
        "Subprocurador-geral do trabalho",
        "Delegado de polícia",
        "Defensor público",
        "Procurador da assistência judiciária",
        "Oficial de inteligência",
        "Oficial técnico de inteligência",
        "Antropólogo",
        "Arqueólogo",
        "Cientista político",
        "Sociólogo",
        "Economista",
        "Economista agroindustrial",
        "Economista financeiro",
        "Economista industrial",
        "Economista do setor público",
        "Economista ambiental",
        "Economista regional e urbano",
        "Geógrafo",
        "Filósofo",
        "Psicólogo educacional",
        "Psicólogo clínico",
        "Psicólogo do esporte",
        "Psicólogo hospitalar",
        "Psicólogo jurídico",
        "Psicólogo social",
        "Psicólogo do trânsito",
        "Psicólogo do trabalho",
        "Neuropsicólogo",
        "Psicanalista",
        "Psicólogo acupunturista",
        "Assistente social",
        "Economista doméstico",
        "Administrador",
        "Auditor (contadores e afins)",
        "Contador",
        "Perito contábil",
        "Secretária(o) executiva(o)",
        "Secretário  bilíngüe",
        "Secretária trilíngüe",
        "Tecnólogo em secretariado escolar",
        "Analista de recursos humanos",
        "Administrador de fundos e carteiras de investimento",
        "Analista de câmbio",
        "Analista de cobrança (instituições financeiras)",
        "Analista de crédito (instituições financeiras)",
        "Analista de crédito rural",
        "Analista de leasing",
        "Analista de produtos bancários",
        "Analista financeiro (instituições financeiras)",
        "Profissional de relações com investidores",
        "Gestor em segurança",
        "Analista de pcp (programação e controle da produção)",
        "Analista de planejamento de materias",
        "Analista de logistica",
        "Analista de projetos logisticos",
        "Analista de gestão de estoque",
        "Redator de publicidade",
        "Publicitário",
        "Diretor de mídia (publicidade)",
        "Diretor de arte (publicidade)",
        "Diretor de criação",
        "Diretor de contas (publicidade)",
        "Agenciador de propaganda",
        "Gerente de captação (fundos e investimentos institucionais)",
        "Gerente de clientes especiais (private)",
        "Gerente de contas - pessoa física e jurídica",
        "Gerente de grandes contas (corporate)",
        "Operador de negócios",
        "Corretor de valores, ativos financeiros, mercadorias e derivativos",
        "Analista de mídias sociais",
        "Influenciador digital",
        "Auditor-fiscal da receita federal",
        "Técnico da receita federal",
        "Auditor-fiscal da previdência social",
        "Auditor-fiscal do trabalho",
        "Agente de higiene e segurança",
        "Fiscal de tributos estadual",
        "Fiscal de tributos municipal",
        "Técnico de tributos estadual",
        "Técnico de tributos municipal",
        "Fiscal de atividades urbanas",
        "Arquivista pesquisador (jornalismo)",
        "Assessor de imprensa",
        "Diretor de redação",
        "Editor",
        "Jornalista",
        "Produtor de texto",
        "Repórter (exclusive rádio e televisão)",
        "Revisor de texto",
        "Bibliotecário",
        "Documentalista",
        "Analista de informações (pesquisador de informações de rede)",
        "Arquivista",
        "Museólogo",
        "Filólogo",
        "Intérprete",
        "Lingüista",
        "Tradutor",
        "Intérprete de língua de sinais",
        "Audiodescritor",
        "Autor-roteirista",
        "Crítico",
        "Escritor de ficção",
        "Escritor de não ficção",
        "Poeta",
        "Redator de textos técnicos",
        "Editor de jornal",
        "Editor de livro",
        "Editor de mídia eletrônica",
        "Editor de revista",
        "Editor de revista científica",
        "Âncora de mídias audiovisuais",
        "Comentarista de mídias audiovisuais",
        "Locutor de mídias audiovisuais",
        "Repórter de mídias audiovisuais",
        "Fotógrafo",
        "Fotógrafo publicitário",
        "Fotógrafo retratista",
        "Repórter fotográfico",
        "Continuista",
        "Assistente de direção (tv)",
        "Produtor cultural",
        "Produtor cinematográfico",
        "Produtor de rádio",
        "Produtor de teatro",
        "Produtor de televisão",
        "Tecnólogo em produção fonográfica",
        "Tecnólogo em produção audiovisual",
        "Diretor de cinema",
        "Diretor de programas de rádio",
        "Diretor de programas de televisão",
        "Diretor teatral",
        "Diretor de programação",
        "Diretor de produção",
        "Diretor artistíco",
        "Cenógrafo carnavalesco e festas populares",
        "Cenógrafo de cinema",
        "Cenógrafo de eventos",
        "Cenógrafo de teatro",
        "Cenógrafo de tv",
        "Diretor de arte",
        "Artista (artes visuais)",
        "Desenhista industrial gráfico (designer gráfico)",
        "Conservador-restaurador de bens  culturais",
        "Desenhista industrial de produto (designer de produto)",
        "Desenhista industrial de produto de moda (designer de moda)",
        "Ator",
        "Compositor",
        "Músico arranjador",
        "Músico regente",
        "Musicólogo",
        "Músico intérprete cantor",
        "Músico intérprete instrumentista",
        "Assistente de coreografia",
        "Bailarino (exceto danças populares)",
        "Coreógrafo",
        "Dramaturgo de dança",
        "Ensaiador de dança",
        "Professor de dança",
        "Decorador de interiores de nível superior",
        "Ministro de culto religioso",
        "Missionário",
        "Teólogo",
        "Chefe de cozinha",
        "Tecnólogo em gastronomia",
        "Técnico em mecatrônica - automação da manufatura",
        "Técnico em mecatrônica - robótica",
        "Técnico em eletromecânica",
        "Técnico de laboratório industrial",
        "Técnico de laboratório de análises físico-químicas (materiais de construção)",
        "Técnico químico de petróleo",
        "Técnico de apoio à bioengenharia",
        "Técnico químico",
        "Técnico de celulose e papel",
        "Técnico em curtimento",
        "Técnico em petroquímica",
        "Técnico em materiais, produtos cerâmicos e vidros",
        "Técnico em borracha",
        "Técnico em plástico",
        "Técnico de controle de meio ambiente",
        "Técnico de meteorologia",
        "Técnico de utilidade (produção e distribuição de vapor, gases, óleos, combustíveis, energia)",
        "Técnico em tratamento de efluentes",
        "Técnico têxtil",
        "Técnico têxtil (tratamentos químicos)",
        "Técnico têxtil de fiação",
        "Técnico têxtil de malharia",
        "Técnico têxtil de tecelagem",
        "Colorista de papel",
        "Colorista têxtil",
        "Preparador de tintas",
        "Preparador de tintas (fábrica de tecidos)",
        "Tingidor de couros e peles",
        "Técnico de obras civis",
        "Técnico de estradas",
        "Técnico de saneamento",
        "Técnico em agrimensura",
        "Técnico em geodésia e cartografia",
        "Técnico em hidrografia",
        "Topógrafo",
        "Eletrotécnico",
        "Eletrotécnico (produção de energia)",
        "Eletrotécnico na fabricação, montagem e instalação de máquinas e equipamentos",
        "Técnico de manutenção elétrica",
        "Técnico de manutenção elétrica de máquina",
        "Técnico eletricista",
        "Técnico de manutenção eletrônica",
        "Técnico de manutenção eletrônica (circuitos de máquinas com comando numérico)",
        "Técnico eletrônico",
        "Técnico em manutenção de equipamentos de informática",
        "Técnico de comunicação de dados",
        "Técnico de rede (telecomunicações)",
        "Técnico de telecomunicações (telefonia)",
        "Técnico de transmissão (telecomunicações)",
        "Técnico em calibração",
        "Técnico em instrumentação",
        "Encarregado de manutenção de instrumentos de controle, medição e similares",
        "Técnico em fotônica",
        "Técnico em mecânica de precisão",
        "Técnico mecânico",
        "Técnico mecânico (calefação, ventilação e refrigeração)",
        "Técnico mecânico (máquinas)",
        "Técnico mecânico (motores)",
        "Técnico mecânico na fabricação de ferramentas",
        "Técnico mecânico na manutenção de ferramentas",
        "Técnico em automobilística",
        "Técnico mecânico (aeronaves)",
        "Técnico mecânico (embarcações)",
        "Técnico de manutenção de sistemas e instrumentos",
        "Técnico em manutenção de máquinas",
        "Técnico em caldeiraria",
        "Técnico em estruturas metálicas",
        "Técnico em soldagem",
        "Tecnólogo em soldagem",
        "Técnico de acabamento em siderurgia",
        "Técnico de aciaria em siderurgia",
        "Técnico de fundição em siderurgia",
        "Técnico de laminação em siderurgia",
        "Técnico de redução na siderurgia (primeira fusão)",
        "Técnico de refratário em siderurgia",
        "Inspetor de equipamentos",
        "Inspetor de fabricação",
        "Inspetor de ensaios não destrutivos",
        "Inspetor de dutos",
        "Inspetor de controle dimensional",
        "Inspetor de pintura",
        "Inspetor de manutenção",
        "Inspetor de soldagem",
        "Técnico em geofísica",
        "Técnico em geologia",
        "Técnico em geoquímica",
        "Técnico em geotecnia",
        "Técnico de mineração",
        "Técnico de mineração (óleo e petróleo)",
        "Técnico em processamento mineral (exceto petróleo)",
        "Técnico em pesquisa mineral",
        "Técnico de produção em refino de petróleo",
        "Técnico em planejamento de lavra de minas",
        "Desincrustador (poços de petróleo)",
        "Cimentador (poços de petróleo)",
        "Desenvolvedor web (técnico)",
        "Desenvolvedor de sistemas de tecnologia da informação (técnico)",
        "Programador de máquinas - ferramenta com comando numérico",
        "Desenvolvedor de multimídia",
        "Operador de computador",
        "Técnico de suporte ao usuário de tecnologia da informação",
        "Desenhista técnico",
        "Desenhista copista",
        "Desenhista detalhista",
        "Desenhista técnico (arquitetura)",
        "Desenhista técnico (cartografia)",
        "Desenhista técnico (construção civil)",
        "Desenhista técnico (instalações hidrossanitárias)",
        "Desenhista técnico mecânico",
        "Desenhista técnico aeronáutico",
        "Desenhista técnico naval",
        "Desenhista técnico (eletricidade e eletrônica)",
        "Desenhista técnico (calefação, ventilação e refrigeração)",
        "Desenhista técnico (artes gráficas)",
        "Desenhista técnico (ilustrações artísticas)",
        "Desenhista técnico (ilustrações técnicas)",
        "Desenhista técnico (indústria têxtil)",
        "Desenhista técnico (mobiliário)",
        "Desenhista técnico de embalagens, maquetes e leiautes",
        "Desenhista projetista de arquitetura",
        "Desenhista projetista de construção civil",
        "Desenhista projetista de máquinas",
        "Desenhista projetista mecânico",
        "Desenhista projetista de eletricidade",
        "Desenhista projetista eletrônico",
        "Projetista de móveis",
        "Modelista de roupas",
        "Modelista de calçados",
        "Técnico em calçados e artefatos de couro",
        "Técnico em confecções do vestuário",
        "Técnico do mobiliário",
        "Técnico em bioterismo",
        "Técnico em histologia",
        "Técnico agrícola",
        "Técnico agropecuário",
        "Técnico em madeira",
        "Técnico florestal",
        "Técnico em piscicultura",
        "Técnico em carcinicultura",
        "Técnico em mitilicultura",
        "Técnico em ranicultura",
        "Técnico em acupuntura",
        "Podólogo",
        "Técnico em quiropraxia",
        "Massoterapeuta",
        "Terapeuta holístico",
        "Esteticista",
        "Doula",
        "Instrutor de pilates",
        "Técnico de enfermagem",
        "Técnico de enfermagem de terapia intensiva",
        "Técnico de enfermagem do trabalho",
        "Técnico de enfermagem psiquiátrica",
        "Instrumentador cirúrgico",
        "Auxiliar de enfermagem",
        "Auxiliar de enfermagem do trabalho",
        "Auxiliar de saúde (navegação marítima)",
        "Técnico de enfermagem da estratégia de saúde da família",
        "Auxiliar de enfermagem da estratégia de saúde da família",
        "Técnico em agente comunitário de saúde",
        "Técnico em óptica e optometria",
        "Técnico em saúde bucal",
        "Protético dentário",
        "Auxiliar em saúde bucal",
        "Auxiliar de prótese dentária",
        "Técnico em saúde bucal da estratégia de saúde da família",
        "Auxiliar em saúde bucal da estratégia de saúde da família",
        "Técnico de ortopedia",
        "Técnico de imobilização ortopédica",
        "Técnico em pecuária",
        "Técnico em métodos eletrográficos em encefalografia",
        "Técnico em métodos gráficos em cardiologia",
        "Técnico em radiologia e imagenologia",
        "Tecnólogo em radiologia",
        "Tecnólogo oftálmico",
        "Técnico em espirometria",
        "Técnico em polissonografia",
        "Dosimetrista clínico",
        "Técnico em patologia clínica",
        "Citotécnico",
        "Técnico em hemoterapia",
        "Enólogo",
        "Aromista",
        "Perfumista",
        "Auxiliar técnico em laboratório de farmácia",
        "Técnico em laboratório de farmácia",
        "Técnico em farmácia",
        "Técnico de alimentos",
        "Técnico em nutrição e dietética",
        "Técnico em biotecnologia",
        "Técnico em imunobiológicos",
        "Embalsamador",
        "Taxidermista",
        "Professor de nível médio na educação infantil",
        "Auxiliar de desenvolvimento infantil",
        "Professor de nível médio no ensino fundamental",
        "Professor de nível médio no ensino profissionalizante",
        "Professor leigo no ensino fundamental",
        "Professor prático no ensino profissionalizante",
        "Instrutor de auto-escola",
        "Instrutor de cursos livres",
        "Professores de cursos livres",
        "Inspetor de alunos de escola privada",
        "Inspetor de alunos de escola pública",
        "Monitor de transporte escolar",
        "Piloto comercial (exceto linhas aéreas)",
        "Piloto comercial de helicóptero (exceto linhas aéreas)",
        "Mecânico de vôo",
        "Piloto agrícola",
        "Contramestre de cabotagem",
        "Mestre de cabotagem",
        "Mestre fluvial",
        "Patrão de pesca de alto-mar",
        "Patrão de pesca na navegação interior",
        "Piloto fluvial",
        "Técnico em sinalização náutica",
        "Técnicos em manobras em equipamentos de convés",
        "Técnico em sinais navais",
        "Auxiliar técnico de sinalização nautica",
        "Condutor maquinista motorista fluvial",
        "Condutor de máquinas",
        "Eletricista de bordo",
        "Condutor de máquinas (bombeador)",
        "Condutor de máquinas (mecânico)",
        "Analista de transporte em comércio exterior",
        "Operador de transporte multimodal",
        "Controlador de serviços de máquinas e veículos",
        "Afretador",
        "Tecnólogo em logística de transporte",
        "Ajudante de despachante aduaneiro",
        "Despachante aduaneiro",
        "Analista de desembaraço aduaneiro",
        "Chefe de serviço de transporte rodoviário (passageiros e cargas)",
        "Inspetor de serviços de transportes rodoviários (passageiros e cargas)",
        "Supervisor de carga e descarga",
        "Agente de estação (ferrovia e metrô)",
        "Operador de centro de controle (ferrovia e metrô)",
        "Controlador de tráfego aéreo",
        "Despachante operacional de vôo",
        "Fiscal de aviação civil (fac)",
        "Inspetor de aviação civil",
        "Operador de atendimento aeroviário",
        "Supervisor da administração de aeroportos",
        "Supervisor de empresa aérea em aeroportos",
        "Agente de proteção de aviação civil",
        "Fiscal de pista de aeroporto",
        "Operador de rampa ( transporte aéreo)",
        "Chefe de estação portuária",
        "Supervisor de operações portuárias",
        "Técnico de contabilidade",
        "Chefe de contabilidade (técnico)",
        "Consultor contábil (técnico)",
        "Técnico em administração",
        "Técnico em administração de comércio exterior",
        "Agente de recrutamento e seleção",
        "Escrevente",
        "Escrivão judicial",
        "Escrivão extra - judicial",
        "Escrivão de polícia",
        "Oficial de justiça",
        "Auxiliar de serviços jurídicos",
        "Mediador de conflitos",
        "Árbitro extrajudicial",
        "Técnico em secretariado",
        "Taquígrafo",
        "Estenotipista",
        "Técnico em segurança do trabalho",
        "Técnico em higiene ocupacional",
        "Analista de seguros (técnico)",
        "Analista de sinistros",
        "Assistente comercial de seguros",
        "Assistente técnico de seguros",
        "Inspetor de risco",
        "Inspetor de sinistros",
        "Técnico de resseguros",
        "Técnico de seguros",
        "Detetive profissional",
        "Investigador de polícia",
        "Papiloscopista policial",
        "Agente de inteligência",
        "Agente técnico de inteligência",
        "Agente de defesa ambiental",
        "Agente de saúde pública",
        "Metrologista",
        "Agente fiscal de qualidade",
        "Agente fiscal metrológico",
        "Agente fiscal têxtil",
        "Agente de direitos autorais",
        "Avaliador de produtos dos meios de comunicação",
        "Técnico em direitos autorais",
        "Técnico de operações e serviços bancários - câmbio",
        "Técnico de operações e serviços bancários - crédito imobiliário",
        "Técnico de operações e serviços bancários - crédito rural",
        "Técnico de operações e serviços bancários - leasing",
        "Técnico de operações e serviços bancários - renda fixa e variável",
        "Tesoureiro de banco",
        "Chefe de serviços bancários",
        "Agente de vendas de serviços",
        "Assistente de vendas",
        "Promotor de vendas especializado",
        "Técnico de vendas",
        "Técnico em atendimento e vendas",
        "Vendedor pracista",
        "Propagandista de produtos famacêuticos",
        "Comprador",
        "Supervisor de compras",
        "Analista de exportação e importação",
        "Leiloeiro",
        "Avaliador de imóveis",
        "Avaliador de bens móveis",
        "Corretor de seguros",
        "Corretor de imóveis",
        "Corretor de grãos",
        "Representante comercial autônomo",
        "Técnico em turismo",
        "Operador de turismo",
        "Agente de viagem",
        "Organizador de evento",
        "Cerimonialista",
        "Auxiliar de biblioteca",
        "Técnico em biblioteconomia",
        "Colecionador de selos e moedas",
        "Técnico em museologia",
        "Técnico em programação visual",
        "Técnico gráfico",
        "Recreador de acantonamento",
        "Recreador",
        "Diretor de fotografia",
        "Iluminador (televisão)",
        "Operador de câmera de televisão",
        "Operador de rede de teleprocessamento",
        "Radiotelegrafista",
        "Operador de mídia audiovisual",
        "Técnico de sistemas audiovisuais",
        "Operador de controle mestre",
        "Coordenador de programação",
        "Assistente de operações audiovisuais",
        "Supervisor técnico operacional de sistemas de televisão e produtoras de vídeo",
        "Supervisor de operações (mídias audiovisuais)",
        "Supervisor técnico (mídias audiovisuais)",
        "Técnico em gravação de áudio",
        "Técnico em instalação de equipamentos de áudio",
        "Técnico em masterização de áudio",
        "Projetista de som",
        "Técnico em sonorização",
        "Técnico em mixagem de áudio",
        "Projetista de sistemas de áudio",
        "Microfonista",
        "Dj (disc jockey)",
        "Sonoplasta",
        "Analista musical",
        "Cenotécnico (cinema, vídeo, televisão, teatro e espetáculos)",
        "Maquinista de cinema e vídeo",
        "Maquinista de teatro e espetáculos",
        "Operador de projetor cinematográfico",
        "Operador-mantenedor de projetor cinematográfico",
        "Editor de mídia audiovisual",
        "Finalizador de filmes",
        "Finalizador de vídeo",
        "Montador de filmes",
        "Diretor de imagens (tv)",
        "Designer de interiores",
        "Designer de vitrines",
        "Visual merchandiser",
        "Decorador de eventos",
        "Produtor de moda",
        "Profissional de organização (personal organizer)",
        "Dançarino tradicional",
        "Dançarino popular",
        "Acrobata",
        "Artista aéreo",
        "Artista de circo (outros)",
        "Contorcionista",
        "Domador de animais (circense)",
        "Equilibrista",
        "Mágico",
        "Malabarista",
        "Palhaço",
        "Titeriteiro",
        "Trapezista",
        "Apresentador de eventos",
        "Apresentador de festas populares",
        "Apresentador de programas de rádio",
        "Apresentador de programas de televisão",
        "Apresentador de circo",
        "Mestre de cerimonias",
        "Modelo artístico",
        "Modelo de modas",
        "Modelo publicitário",
        "Atleta profissional (outras modalidades)",
        "Atleta profissional de futebol",
        "Atleta profissional de golfe",
        "Atleta profissional de luta",
        "Atleta profissional de tênis",
        "Jóquei",
        "Piloto de competição automobilística",
        "Profissional de atletismo",
        "Pugilista",
        "Árbitro desportivo",
        "Árbitro de atletismo",
        "Árbitro de basquete",
        "Árbitro de futebol",
        "Árbitro de futebol de salão",
        "Árbitro de judô",
        "Árbitro de karatê",
        "Árbitro de poló aquático",
        "Árbitro de vôlei",
        "Cronoanalista",
        "Cronometrista",
        "Controlador de entrada e saída",
        "Planejista",
        "Técnico de planejamento de produção",
        "Técnico de planejamento e programação da manutenção",
        "Técnico de matéria-prima e material",
        "Analista de manutenção (equipamentos aéreos)",
        "Analista de planejamento de manutenção",
        "Inspetor de qualidade",
        "Técnico de garantia da qualidade",
        "Operador de inspeção de qualidade",
        "Técnico de painel de controle",
        "Escolhedor de papel",
        "Técnico operacional de serviços de correios",
        "Técnico de apoio em pesquisa e desenvolvimento (exceto agropecuário e florestal)",
        "Técnico de apoio em pesquisa e desenvolvimento agropecuário florestal",
        "Supervisor administrativo",
        "Supervisor de almoxarifado",
        "Supervisor de câmbio",
        "Supervisor de contas a pagar",
        "Supervisor de controle patrimonial",
        "Supervisor de crédito e cobrança",
        "Supervisor de orçamento",
        "Supervisor de tesouraria",
        "Supervisor de logística",
        "Auxiliar de escritório",
        "Assistente administrativo",
        "Atendente de judiciário",
        "Auxiliar de judiciário",
        "Auxiliar de cartório",
        "Auxiliar de pessoal",
        "Auxiliar de estatística",
        "Auxiliar de seguros",
        "Auxiliar de serviços de importação e exportação",
        "Agente de microcrédito",
        "Captador de recursos",
        "Datilógrafo",
        "Digitador",
        "Operador de mensagens de telecomunicações (correios)",
        "Supervisor de digitação e operação",
        "Contínuo",
        "Analista de folha de pagamento",
        "Auxiliar de contabilidade",
        "Auxiliar de faturamento",
        "Atendente de agência",
        "Caixa de banco",
        "Compensador de banco",
        "Conferente de serviços bancários",
        "Escriturário de banco",
        "Operador de cobrança bancária",
        "Almoxarife",
        "Armazenista",
        "Balanceiro",
        "Conferente mercadoria (exceto carga e descarga)",
        "Estoquista",
        "Expedidor de mercadorias",
        "Auxiliar de logistica",
        "Apontador de mão-de-obra",
        "Apontador de produção",
        "Conferente de carga e descarga",
        "Arquivista de documentos",
        "Codificador de dados",
        "Fitotecário",
        "Kardexista",
        "Operador de máquina copiadora (exceto operador de gráfica rápida)",
        "Carteiro",
        "Operador de triagem e transbordo",
        "Entregador de publicações",
        "Registrador de câncer",
        "Analista de informação em saúde",
        "Supervisor de caixas e bilheteiros (exceto caixa de banco)",
        "Supervisor de cobrança",
        "Supervisor de coletadores de apostas e de jogos",
        "Supervisor de entrevistadores e recenseadores",
        "Supervisor de recepcionistas",
        "Supervisor de telefonistas",
        "Supervisor de telemarketing e atendimento",
        "Atendente comercial (agência postal)",
        "Bilheteiro de transportes coletivos",
        "Bilheteiro no serviço de diversões",
        "Emissor de passagens",
        "Operador de caixa",
        "Recebedor de apostas (loteria)",
        "Recebedor de apostas (turfe)",
        "Cobrador externo",
        "Cobrador interno",
        "Localizador (cobrador)",
        "Recepcionista, em geral",
        "Recepcionista de consultório médico ou dentário",
        "Recepcionista de seguro saúde",
        "Recepcionista de hotel",
        "Recepcionista de banco",
        "Concierge",
        "Telefonista",
        "Teleoperador",
        "Operador de rádio-chamada",
        "Operador de telemarketing ativo",
        "Operador de telemarketing ativo e receptivo",
        "Operador de telemarketing receptivo",
        "Operador de telemarketing técnico",
        "Teleatendente de emergência",
        "Monitor de teleatendimento",
        "Despachante documentalista",
        "Despachante de trânsito",
        "Vistoriador veicular",
        "Entrevistador censitário e de pesquisas amostrais",
        "Entrevistador de pesquisa de opinião e mídia",
        "Entrevistador de pesquisas de mercado",
        "Entrevistador de preços",
        "Escriturário  em  estatística",
        "Entrevistador social",
        "Coordenador de provas (concurso, avaliação, exame)",
        "Aplicador de provas (concurso, avaliação,exame)",
        "Supervisor de transportes",
        "Administrador de edifícios",
        "Supervisor de andar",
        "Chefe de portaria de hotel",
        "Chefe de bar",
        "Maître",
        "Supervisor de lavanderia",
        "Supervisor de bombeiros",
        "Supervisor de vigilantes",
        "Comissário de vôo",
        "Comissário de trem",
        "Taifeiro (exceto militares)",
        "Fiscal de transportes coletivos (exceto trem)",
        "Despachante de transportes coletivos (exceto trem)",
        "Cobrador de transportes coletivos (exceto trem)",
        "Bilheteiro (estações de metrô, ferroviárias e assemelhadas)",
        "Guia de turismo",
        "Condutor de turismo de aventura",
        "Condutor de turismo de pesca",
        "Condutor turismo náutico",
        "Empregado  doméstico  nos serviços gerais",
        "Empregado doméstico  arrumador",
        "Empregado doméstico  faxineiro",
        "Empregado doméstico diarista",
        "Mordomo de residência",
        "Mordomo de hotelaria",
        "Governanta de hotelaria",
        "Cozinheiro geral",
        "Cozinheiro do serviço doméstico",
        "Cozinheiro industrial",
        "Cozinheiro de hospital",
        "Cozinheiro de embarcações",
        "Camareiro de teatro",
        "Camareiro de televisão",
        "Camareiro  de hotel",
        "Camareiro de embarcações",
        "Guarda-roupeiro de cinema",
        "Garçom",
        "Sommelier",
        "Cumim",
        "Barman",
        "Copeiro",
        "Copeiro de hospital",
        "Atendente de lanchonete",
        "Barista",
        "Auxiliar nos serviços de alimentação",
        "Churrasqueiro",
        "Pizzaiolo",
        "Sushiman",
        "Ascensorista",
        "Garagista",
        "Sacristão",
        "Zelador de edifício",
        "Coletor de lixo domiciliar",
        "Varredor de rua",
        "Trabalhador de serviços de limpeza e conservação de áreas públicas",
        "Coletor de resíduos sólidos de serviços de saúde",
        "Limpador de vidros",
        "Auxiliar de manutenção predial",
        "Limpador de fachadas",
        "Faxineiro",
        "Trabalhador da manutenção de edificações",
        "Limpador de piscinas",
        "Agente comunitário de saúde",
        "Atendente de enfermagem",
        "Parteira leiga",
        "Visitador sanitário",
        "Agente indígena de saúde",
        "Agente indígena de saneamento",
        "Socorrista (exceto médicos e enfermeiros)",
        "Agente de combate às endemias",
        "Auxiliar de banco de sangue",
        "Auxiliar de farmácia de manipulação",
        "Auxiliar de laboratório de análises clínicas",
        "Auxiliar de laboratório de imunobiológicos",
        "Auxiliar de produção farmacêutica",
        "Educador social",
        "Agente de ação social",
        "Monitor de dependente químico",
        "Conselheiro tutelar",
        "Sócioeducador",
        "Monitor de ressocialização prisional",
        "Barbeiro",
        "Cabeleireiro",
        "Manicure/pedicure",
        "Maquiador",
        "Maquiador de caracterização",
        "Designer de unhas",
        "Designer de sobrancelhas",
        "Designer de cílios",
        "Babá",
        "Cuidador de idosos",
        "Mãe social",
        "Cuidador em saúde",
        "Lavadeiro, em geral",
        "Lavador de roupas  a maquina",
        "Lavador de artefatos de tapeçaria",
        "Limpador a seco, à máquina",
        "Passador de roupas em geral",
        "Tingidor de roupas",
        "Conferente-expedidor de roupas (lavanderias)",
        "Atendente de lavanderia",
        "Auxiliar de lavanderia",
        "Lavador de roupas",
        "Limpador de roupas a seco, à mão",
        "Passador de roupas, à mão",
        "Agente funerário",
        "Operador de forno (serviços funerários)",
        "Sepultador",
        "Astrólogo",
        "Numerólogo",
        "Esotérico",
        "Paranormal",
        "Tatuador",
        "Micropigmentador",
        "Body piercer",
        "Bombeiro de aeródromo",
        "Bombeiro civil",
        "Salva-vidas",
        "Brigadista florestal",
        "Chefe de brigada",
        "Agente de proteção e defesa civil",
        "Agente de polícia federal",
        "Policial rodoviário federal",
        "Guarda-civil municipal",
        "Agente de trânsito",
        "Policial legislativo",
        "Policial penal",
        "Guarda portuário",
        "Vigilante de proteção de aeroporto",
        "Agente de segurança",
        "Vigia florestal",
        "Vigia portuário",
        "Vigilante",
        "Porteiro (hotel)",
        "Porteiro de edifícios",
        "Agente de portaria",
        "Vigia",
        "Fiscal de loja",
        "Ciclista mensageiro",
        "Motofretista",
        "Mototaxista",
        "Catador de material reciclável",
        "Selecionador de material reciclável",
        "Operador de prensa de material reciclável",
        "Auxiliar de veterinário",
        "Esteticista de animais domésticos",
        "Banhista de animais domésticos",
        "Tosador de animais domésticos",
        "Profissional do sexo",
        "Cartazeiro",
        "Controlador de pragas",
        "Engraxate",
        "Gandula",
        "Guardador de veículos",
        "Lavador de garrafas, vidros e outros utensílios",
        "Lavador de veículos",
        "Leiturista",
        "Recepcionista de casas de espetáculos",
        "Supervisor de vendas de serviços",
        "Supervisor de vendas comercial",
        "Vendedor em comércio atacadista",
        "Vendedor de comércio varejista",
        "Promotor de vendas",
        "Demonstrador de mercadorias",
        "Repositor de mercadorias",
        "Atendente de farmácia - balconista",
        "Frentista",
        "Atendente de lojas e mercados",
        "Instalador de cortinas e persianas, portas sanfonadas e boxe",
        "Instalador de som e acessórios de veículos",
        "Chaveiro",
        "Aplicador de vinil autoadesivo",
        "Estampador de placa de identificação veicular (epiv)",
        "Vendedor em domicílio",
        "Feirante",
        "Jornaleiro (em banca de jornal)",
        "Vendedor  permissionário",
        "Vendedor ambulante",
        "Pipoqueiro ambulante",
        "Baiana de acarajé",
        "Produtor agropecuário, em geral",
        "Produtor agrícola polivalente",
        "Produtor de arroz",
        "Produtor de cana-de-açúcar",
        "Produtor de cereais de inverno",
        "Produtor de gramíneas forrageiras",
        "Produtor de milho e sorgo",
        "Produtor de algodão",
        "Produtor de curauá",
        "Produtor de juta",
        "Produtor de rami",
        "Produtor de sisal",
        "Produtor na olericultura de legumes",
        "Produtor na olericultura de raízes, bulbos e tubérculos",
        "Produtor na olericultura de talos, folhas e flores",
        "Produtor na olericultura de frutos e sementes",
        "Produtor de flores de corte",
        "Produtor de flores em vaso",
        "Produtor de forrações",
        "Produtor de plantas ornamentais",
        "Produtor de árvores frutíferas",
        "Produtor de espécies frutíferas rasteiras",
        "Produtor de espécies frutíferas trepadeiras",
        "Cafeicultor",
        "Produtor de cacau",
        "Produtor de erva-mate",
        "Produtor de fumo",
        "Produtor de guaraná",
        "Produtor da cultura de amendoim",
        "Produtor da cultura de canola",
        "Produtor da cultura de coco-da-baia",
        "Produtor da cultura de dendê",
        "Produtor da cultura de girassol",
        "Produtor da cultura de linho",
        "Produtor da cultura de mamona",
        "Produtor da cultura de soja",
        "Produtor de especiarias",
        "Produtor de plantas aromáticas e medicinais",
        "Criador em pecuária polivalente",
        "Criador de animais domésticos",
        "Criador de asininos e muares",
        "Criador de bovinos (corte)",
        "Criador de bovinos (leite)",
        "Criador de bubalinos (corte)",
        "Criador de bubalinos (leite)",
        "Criador de eqüínos",
        "Criador de caprinos",
        "Criador de ovinos",
        "Criador de suínos",
        "Avicultor",
        "Cunicultor",
        "Apicultor",
        "Criador de animais produtores de veneno",
        "Minhocultor",
        "Sericultor",
        "Supervisor de exploração agrícola",
        "Supervisor de exploração agropecuária",
        "Supervisor de exploração pecuária",
        "Trabalhador agropecuário em geral",
        "Caseiro (agricultura)",
        "Jardineiro",
        "Trabalhador na produção de mudas e sementes",
        "Trabalhador volante da agricultura",
        "Trabalhador da cultura de arroz",
        "Trabalhador da cultura de cana-de-açúcar",
        "Trabalhador da cultura de milho e sorgo",
        "Trabalhador da cultura de trigo, aveia, cevada e triticale",
        "Trabalhador da cultura de algodão",
        "Trabalhador da cultura de sisal",
        "Trabalhador da cultura do rami",
        "Trabalhador na olericultura (frutos e sementes)",
        "Trabalhador na olericultura (legumes)",
        "Trabalhador na olericultura (raízes, bulbos e tubérculos)",
        "Trabalhador na olericultura (talos, folhas e flores)",
        "Trabalhador no cultivo de flores e folhagens de corte",
        "Trabalhador no cultivo de flores em vaso",
        "Trabalhador no cultivo de forrações",
        "Trabalhador no cultivo de mudas",
        "Trabalhador no cultivo de plantas ornamentais",
        "Trabalhador no cultivo de árvores frutíferas",
        "Trabalhador no cultivo de espécies frutíferas rasteiras",
        "Trabalhador no cultivo de trepadeiras frutíferas",
        "Trabalhador da cultura de cacau",
        "Trabalhador da cultura de café",
        "Trabalhador da cultura de erva-mate",
        "Trabalhador da cultura de fumo",
        "Trabalhador da cultura de guaraná",
        "Trabalhador na cultura de amendoim",
        "Trabalhador na cultura de canola",
        "Trabalhador na cultura de coco-da-baía",
        "Trabalhador na cultura de dendê",
        "Trabalhador na cultura de mamona",
        "Trabalhador na cultura de soja",
        "Trabalhador na cultura do girassol",
        "Trabalhador na cultura do linho",
        "Trabalhador da cultura de especiarias",
        "Trabalhador da cultura de plantas aromáticas e medicinais",
        "Adestrador de animais",
        "Inseminador",
        "Trabalhador de pecuária polivalente",
        "Tratador de animais",
        "Casqueador de animais",
        "Ferrador de animais",
        "Trabalhador da pecuária (asininos e muares)",
        "Trabalhador da pecuária (bovinos corte)",
        "Trabalhador da pecuária (bovinos leite)",
        "Trabalhador da pecuária (bubalinos)",
        "Trabalhador da pecuária (eqüinos)",
        "Trabalhador da caprinocultura",
        "Trabalhador da ovinocultura",
        "Trabalhador da suinocultura",
        "Trabalhador da avicultura de corte",
        "Trabalhador da avicultura de postura",
        "Operador de incubadora",
        "Trabalhador da cunicultura",
        "Sexador",
        "Trabalhador em criatórios de animais produtores de veneno",
        "Trabalhador na apicultura",
        "Trabalhador na minhocultura",
        "Trabalhador na sericicultura",
        "Supervisor da aqüicultura",
        "Supervisor da área florestal",
        "Catador de caranguejos e siris",
        "Catador de mariscos",
        "Pescador artesanal de lagostas",
        "Pescador artesanal de peixes e camarões",
        "Pescador artesanal de água doce",
        "Pescador industrial",
        "Pescador profissional",
        "Criador de camarões",
        "Criador de jacarés",
        "Criador de mexilhões",
        "Criador de ostras",
        "Criador de peixes",
        "Criador de quelônios",
        "Criador de rãs",
        "Gelador industrial",
        "Gelador profissional",
        "Proeiro",
        "Redeiro (pesca)",
        "Guia florestal",
        "Raizeiro",
        "Viveirista florestal",
        "Classificador de toras",
        "Cubador de madeira",
        "Identificador florestal",
        "Operador de motosserra",
        "Trabalhador de extração florestal, em geral",
        "Seringueiro",
        "Trabalhador da exploração de espécies produtoras de gomas não elásticas",
        "Trabalhador da exploração de resinas",
        "Trabalhador da exploração de andiroba",
        "Trabalhador da exploração de babaçu",
        "Trabalhador da exploração de bacaba",
        "Trabalhador da exploração de buriti",
        "Trabalhador da exploração de carnaúba",
        "Trabalhador da exploração de coco-da-praia",
        "Trabalhador da exploração de copaíba",
        "Trabalhador da exploração de malva (pãina)",
        "Trabalhador da exploração de murumuru",
        "Trabalhador da exploração de oiticica",
        "Trabalhador da exploração de ouricuri",
        "Trabalhador da exploração de pequi",
        "Trabalhador da exploração de piaçava",
        "Trabalhador da exploração de tucum",
        "Trabalhador da exploração de açaí",
        "Trabalhador da exploração de castanha",
        "Trabalhador da exploração de pinhão",
        "Trabalhador da exploração de pupunha",
        "Trabalhador da exploração de árvores e arbustos produtores de substâncias aromát., Medic. E tóxicas",
        "Trabalhador da exploração de cipós produtores de substâncias aromáticas, medicinais e tóxicas",
        "Trabalhador da exploração de madeiras tanantes",
        "Trabalhador da exploração de raízes produtoras de substâncias aromáticas, medicinais e tóxicas",
        "Trabalhador da extração de substâncias aromáticas, medicinais e tóxicas, em geral",
        "Carvoeiro",
        "Carbonizador",
        "Ajudante de carvoaria",
        "Operador de colheitadeira",
        "Operador de máquinas de beneficiamento de produtos agrícolas",
        "Tratorista agrícola",
        "Operador de colhedor florestal",
        "Operador de máquinas florestais estáticas",
        "Operador de trator florestal",
        "Trabalhador na operação de sistema de irrigação localizada (microaspersão e gotejamento)",
        "Trabalhador na operação de sistema de irrigação por aspersão (pivô central)",
        "Trabalhador na operação de sistemas convencionais de irrigação por aspersão",
        "Trabalhador na operação de sistemas de irrigação e aspersão (alto propelido)",
        "Trabalhador na operação de sistemas de irrigação por superfície e drenagem",
        "Supervisor de apoio operacional na mineração",
        "Supervisor de extração de sal",
        "Supervisor de perfuração e desmonte",
        "Supervisor de produção na mineração",
        "Supervisor de transporte na mineração",
        "Mestre (construção civil)",
        "Mestre de linhas (ferrovias)",
        "Inspetor de terraplenagem",
        "Supervisor de usina de concreto",
        "Fiscal de pátio de usina de concreto",
        "Amostrador de minérios",
        "Canteiro",
        "Destroçador de pedra",
        "Detonador",
        "Escorador de minas",
        "Mineiro",
        "Operador de caminhão (minas e pedreiras)",
        "Operador de carregadeira",
        "Operador de máquina cortadora (minas e pedreiras)",
        "Operador de máquina de extração contínua (minas de carvão)",
        "Operador de máquina perfuradora (minas e pedreiras)",
        "Operador de máquina perfuratriz",
        "Operador de motoniveladora (extração de minerais sólidos)",
        "Operador de schutthecar",
        "Operador de trator (minas e pedreiras)",
        "Operador de sonda de percussão",
        "Operador de sonda rotativa",
        "Sondador (poços de petróleo e gás)",
        "Sondador de poços (exceto de petróleo e gás)",
        "Plataformista (petróleo)",
        "Torrista (petróleo)",
        "Garimpeiro",
        "Operador de salina (sal marinho)",
        "Moleiro de minérios",
        "Operador de aparelho de flotação",
        "Operador de aparelho de precipitação (minas de ouro ou prata)",
        "Operador de britador de mandíbulas",
        "Operador de espessador",
        "Operador de jig (minas)",
        "Operador de peneiras hidráulicas",
        "Cortador de pedras",
        "Gravador de inscrições em pedra",
        "Gravador de relevos em pedra",
        "Polidor de pedras",
        "Torneiro (lavra de pedra)",
        "Traçador de pedras",
        "Operador de bate-estacas",
        "Operador de compactadora de solos",
        "Operador de escavadeira",
        "Operador de máquina de abrir valas",
        "Operador de máquinas de construção civil e mineração",
        "Operador de motoniveladora",
        "Operador de pá carregadeira",
        "Operador de pavimentadora (asfalto, concreto e materiais similares)",
        "Operador de trator de lâmina",
        "Calceteiro",
        "Pedreiro",
        "Pedreiro (chaminés industriais)",
        "Pedreiro (material refratário)",
        "Pedreiro (mineração)",
        "Pedreiro de edificações",
        "Armador de estrutura de concreto",
        "Moldador de corpos de prova em usinas de concreto",
        "Armador de estrutura de concreto armado",
        "Operador de betoneira",
        "Operador de bomba de concreto",
        "Operador de central de concreto",
        "Operador de usina de asfalto",
        "Carpinteiro",
        "Carpinteiro (esquadrias)",
        "Carpinteiro (cenários)",
        "Carpinteiro (mineração)",
        "Carpinteiro de obras",
        "Carpinteiro (telhados)",
        "Carpinteiro de fôrmas para concreto",
        "Carpinteiro de obras civis de arte (pontes, túneis, barragens)",
        "Montador de andaimes (edificações)",
        "Eletricista de instalações (cenários)",
        "Eletricista de instalações (edifícios)",
        "Eletricista de instalações",
        "Aplicador de asfalto impermeabilizante (coberturas)",
        "Instalador de isolantes acústicos",
        "Instalador de isolantes térmicos (refrigeração e climatização)",
        "Instalador de isolantes térmicos de caldeira e tubulações",
        "Instalador de material isolante, a mão (edificações)",
        "Instalador de material isolante, à máquina (edificações)",
        "Acabador de superfícies de concreto",
        "Revestidor de superfícies de concreto",
        "Telhador (telhas de argila e materiais similares)",
        "Telhador (telhas de cimento-amianto)",
        "Telhador (telhas metálicas)",
        "Telhador (telhas plásticas)",
        "Vidraceiro",
        "Vidraceiro (edificações)",
        "Vidraceiro (vitrais)",
        "Gesseiro",
        "Assoalhador",
        "Assentador de revestimentos cerâmicos",
        "Pastilheiro",
        "Lustrador de piso",
        "Marmorista (construção)",
        "Mosaísta",
        "Taqueiro",
        "Rejuntador de revestimentos",
        "Calafetador",
        "Pintor de obras",
        "Revestidor de interiores (papel, material plástico e emborrachados)",
        "Demolidor de edificações",
        "Operador de martelete",
        "Poceiro (edificações)",
        "Servente de obras",
        "Vibradorista",
        "Mestre (afiador de ferramentas)",
        "Mestre de caldeiraria",
        "Mestre de ferramentaria",
        "Mestre de forjaria",
        "Mestre de fundição",
        "Mestre de galvanoplastia",
        "Mestre de pintura (tratamento de superfícies)",
        "Mestre de soldagem",
        "Mestre de trefilação de metais",
        "Mestre de usinagem",
        "Mestre serralheiro",
        "Supervisor de controle de tratamento térmico",
        "Mestre (construção naval)",
        "Mestre (indústria de automotores e material de transportes)",
        "Mestre (indústria de máquinas e outros equipamentos mecânicos)",
        "Mestre de construção de fornos",
        "Ferramenteiro",
        "Ferramenteiro de mandris, calibradores e outros dispositivos",
        "Modelador de metais (fundição)",
        "Operador de máquina de eletroerosão",
        "Operador de máquinas operatrizes",
        "Operador de máquinas-ferramenta convencionais",
        "Operador de usinagem convencional por abrasão",
        "Preparador de máquinas-ferramenta",
        "Afiador de cardas",
        "Afiador de cutelaria",
        "Afiador de ferramentas",
        "Afiador de serras",
        "Polidor de metais",
        "Operador de centro de usinagem com comando numérico",
        "Operador de fresadora com comando numérico",
        "Operador de mandriladora com comando numérico",
        "Operador de máquina eletroerosão, à fio, com comando numérico",
        "Operador de retificadora com comando numérico",
        "Operador de torno com comando numérico",
        "Forjador",
        "Forjador a martelo",
        "Forjador prensista",
        "Fundidor de metais",
        "Operador de lingotamento",
        "Operador de acabamento de peças fundidas",
        "Operador de máquina de fundição",
        "Operador de vazamento",
        "Preparador de panelas",
        "Macheiro, a mão",
        "Macheiro, a  máquina",
        "Moldador, a  mão",
        "Moldador, a  máquina",
        "Operador de equipamentos de preparação de areia",
        "Operador de máquina de moldar automatizada",
        "Cableador",
        "Estirador de tubos de metal sem costura",
        "Trefilador de metais, à máquina",
        "Cementador de metais",
        "Normalizador de metais e de compósitos",
        "Operador de equipamento para resfriamento",
        "Operador de forno de tratamento térmico de metais",
        "Temperador de metais e de compósitos",
        "Decapador",
        "Fosfatizador",
        "Galvanizador",
        "Metalizador a pistola",
        "Metalizador (banho quente)",
        "Operador de máquina recobridora de arame",
        "Operador de zincagem (processo eletrolítico)",
        "Oxidador",
        "Operador de equipamento de secagem de pintura",
        "Pintor a pincel e rolo (exceto obras e estruturas metálicas)",
        "Pintor de estruturas metálicas",
        "Pintor de veículos (fabricação)",
        "Pintor por imersão",
        "Pintor, a  pistola (exceto obras e estruturas metálicas)",
        "Assentador de canalização (edificações)",
        "Encanador",
        "Instalador de tubulações",
        "Instalador de tubulações (aeronaves)",
        "Instalador de tubulações (embarcações)",
        "Instalador de tubulações de gás combustível (produção e distribuição)",
        "Instalador de tubulações de vapor (produção e distribuição)",
        "Montador de estruturas metálicas",
        "Montador de estruturas metálicas de embarcações",
        "Rebitador a  martelo pneumático",
        "Preparador de estruturas metálicas",
        "Riscador de estruturas metálicas",
        "Rebitador, a  mão",
        "Brasador",
        "Oxicortador a mão e a  máquina",
        "Soldador",
        "Soldador a  oxigás",
        "Soldador elétrico",
        "Caldeireiro (chapas de cobre)",
        "Caldeireiro (chapas de ferro e aço)",
        "Chapeador",
        "Chapeador de carrocerias metálicas (fabricação)",
        "Chapeador naval",
        "Chapeador de aeronaves",
        "Funileiro industrial",
        "Serralheiro",
        "Operador de máquina de cilindrar chapas",
        "Operador de máquina de dobrar chapas",
        "Prensista (operador de prensa)",
        "Operador de laços de cabos de aço",
        "Trançador de cabos de aço",
        "Ajustador ferramenteiro",
        "Ajustador mecânico",
        "Ajustador mecânico (usinagem em bancada e em máquinas-ferramentas)",
        "Ajustador mecânico em bancada",
        "Ajustador naval (reparo e construção)",
        "Operador de manutenção e recarga de extintor de incêndio",
        "Montador de máquinas, motores e acessórios (montagem em série)",
        "Montador de máquinas",
        "Montador de máquinas gráficas",
        "Montador de máquinas operatrizes para madeira",
        "Montador de máquinas têxteis",
        "Montador de máquinas-ferramentas (usinagem de metais)",
        "Montador de equipamento de levantamento",
        "Montador de máquinas agrícolas",
        "Montador de máquinas de minas e pedreiras",
        "Montador de máquinas de terraplenagem",
        "Mecânico montador de motores de aeronaves",
        "Mecânico montador de motores de embarcações",
        "Mecânico montador de motores de explosão e diesel",
        "Mecânico montador de turboalimentadores",
        "Montador de veículos (linha de montagem)",
        "Operador de time de montagem",
        "Montador de estruturas de aeronaves",
        "Montador de sistemas de combustível de aeronaves",
        "Mecânico de refrigeração",
        "Supervisor de montagem e instalação eletroeletrônica",
        "Montador de equipamentos eletrônicos (aparelhos médicos)",
        "Montador de equipamentos eletrônicos (computadores e equipamentos auxiliares)",
        "Montador de equipamentos elétricos (instrumentos de medição)",
        "Montador de equipamentos elétricos (aparelhos eletrodomésticos)",
        "Montador de equipamentos elétricos (centrais elétricas)",
        "Montador de equipamentos elétricos (motores e dínamos)",
        "Montador de equipamentos elétricos",
        "Montador de equipamentos eletrônicos (instalações de sinalização)",
        "Montador de equipamentos eletrônicos (máquinas industriais)",
        "Montador de equipamentos eletrônicos",
        "Montador de equipamentos elétricos (elevadores e equipamentos similares)",
        "Montador de equipamentos elétricos (transformadores)",
        "Bobinador eletricista, à mão",
        "Bobinador eletricista, à máquina",
        "Operador de linha de montagem (aparelhos elétricos)",
        "Operador de linha de montagem (aparelhos eletrônicos)",
        "Montador de equipamentos eletrônicos (estação de rádio, tv e equipamentos de radar)",
        "Instalador-reparador de equipamentos de comutação em telefonia",
        "Instalador-reparador de equipamentos de energia em telefonia",
        "Instalador-reparador de equipamentos de transmissão em telefonia",
        "Instalador-reparador de linhas e aparelhos de telecomunicações",
        "Instalador-reparador de redes e cabos telefônicos",
        "Reparador de aparelhos de telecomunicações em laboratório",
        "Eletricista de manutenção de linhas elétricas, telefônicas e de comunicação de dados",
        "Emendador de cabos elétricos e telefônicos (aéreos e subterrâneos)",
        "Examinador de cabos, linhas elétricas e telefônicas",
        "Instalador de linhas elétricas de alta e baixa - tensão (rede aérea e subterrânea)",
        "Instalador eletricista (tração de veículos)",
        "Instalador-reparador de redes telefônicas e de comunicação de dados",
        "Ligador de linhas telefônicas",
        "Instalador de sistemas fotovoltaicos",
        "Supervisor da mecânica de precisão",
        "Supervisor de fabricação de instrumentos musicais",
        "Ajustador de instrumentos de precisão",
        "Montador de instrumentos de óptica",
        "Montador de instrumentos de precisão",
        "Relojoeiro (fabricação)",
        "Relojoeiro (reparação)",
        "Afinador de instrumentos musicais",
        "Confeccionador de acordeão",
        "Confeccionador de instrumentos de corda",
        "Confeccionador de instrumentos de percussão (pele, couro ou plástico)",
        "Confeccionador de instrumentos de sopro (madeira)",
        "Confeccionador de instrumentos de sopro (metal)",
        "Confeccionador de órgão",
        "Confeccionador de piano",
        "Supervisor de joalheria",
        "Supervisor da indústria de minerais não metálicos (exceto os derivados de petróleo e carvão)",
        "Engastador (jóias)",
        "Joalheiro",
        "Joalheiro (reparações)",
        "Lapidador (jóias)",
        "Bate-folha a  máquina",
        "Fundidor (joalheria e ourivesaria)",
        "Gravador (joalheria e ourivesaria)",
        "Laminador de metais preciosos a  mão",
        "Ourives",
        "Trefilador (joalheria e ourivesaria)",
        "Artesão modelador (vidros)",
        "Moldador (vidros)",
        "Soprador de vidro",
        "Transformador de tubos de vidro",
        "Aplicador serigráfico em vidros",
        "Cortador de vidro",
        "Gravador de vidro a  água-forte",
        "Gravador de vidro a  esmeril",
        "Gravador de vidro a  jato de areia",
        "Lapidador de vidros e cristais",
        "Surfassagista",
        "Ceramista",
        "Ceramista (torno de pedal e motor)",
        "Ceramista (torno semi-automático)",
        "Ceramista modelador",
        "Ceramista moldador",
        "Ceramista prensador",
        "Decorador de cerâmica",
        "Decorador de vidro",
        "Decorador de vidro à pincel",
        "Operador de esmaltadeira",
        "Operador de espelhamento",
        "Pintor de cerâmica, a  pincel",
        "Contramestre de acabamento (indústria têxtil)",
        "Contramestre de fiação (indústria têxtil)",
        "Contramestre de malharia (indústria têxtil)",
        "Contramestre de tecelagem (indústria têxtil)",
        "Mestre (indústria têxtil e de confecções)",
        "Supervisor de curtimento",
        "Encarregado de corte na confecção do vestuário",
        "Encarregado de costura na confecção do vestuário",
        "Supervisor  (indústria de calçados e artefatos de couro)",
        "Supervisor da confecção de artefatos de tecidos, couros e afins",
        "Supervisor das artes gráficas  (indústria editorial e gráfica)",
        "Operador polivalente da indústria têxtil",
        "Classificador de fibras têxteis",
        "Lavador de lã",
        "Operador de abertura (fiação)",
        "Operador de binadeira",
        "Operador de bobinadeira",
        "Operador de cardas",
        "Operador de conicaleira",
        "Operador de filatório",
        "Operador de laminadeira e reunideira",
        "Operador de maçaroqueira",
        "Operador de open-end",
        "Operador de passador (fiação)",
        "Operador de penteadeira",
        "Operador de retorcedeira",
        "Tecelão (redes)",
        "Tecelão (rendas e bordados)",
        "Tecelão (tear automático)",
        "Tecelão (tear jacquard)",
        "Tecelão (tear mecânico de maquineta)",
        "Tecelão (tear mecânico de xadrez)",
        "Tecelão (tear mecânico liso)",
        "Tecelão (tear mecânico, exceto jacquard)",
        "Tecelão de malhas, a  máquina",
        "Tecelão de malhas (máquina circular)",
        "Tecelão de malhas (máquina retilínea)",
        "Tecelão de meias, a  máquina",
        "Tecelão de meias (máquina circular)",
        "Tecelão de meias (máquina retilínea)",
        "Tecelão de tapetes, a  máquina",
        "Operador de engomadeira de urdume",
        "Operador de espuladeira",
        "Operador de máquina de cordoalha",
        "Operador de urdideira",
        "Passamaneiro a  máquina",
        "Remetedor de fios",
        "Picotador de cartões jacquard",
        "Alvejador (tecidos)",
        "Estampador de tecido",
        "Operador de calandras (tecidos)",
        "Operador de chamuscadeira de tecidos",
        "Operador de impermeabilizador de tecidos",
        "Operador de máquina de lavar fios e tecidos",
        "Operador de rameuse",
        "Inspetor de estamparia (produção têxtil)",
        "Revisor de fios (produção têxtil)",
        "Revisor de tecidos acabados",
        "Revisor de tecidos crus",
        "Trabalhador polivalente do curtimento de couros e peles",
        "Classificador de peles",
        "Descarnador de couros e peles, à maquina",
        "Estirador de couros e peles (preparação)",
        "Fuloneiro",
        "Rachador de couros e peles",
        "Curtidor (couros e peles)",
        "Classificador de couros",
        "Enxugador de couros",
        "Rebaixador de couros",
        "Estirador de couros e peles (acabamento)",
        "Fuloneiro no acabamento de couros e peles",
        "Lixador de couros e peles",
        "Matizador de couros e peles",
        "Operador de máquinas do acabamento de couros e peles",
        "Prensador de couros e peles",
        "Palecionador de couros e peles",
        "Preparador de couros curtidos",
        "Vaqueador de couros e peles",
        "Alfaiate",
        "Costureira de peças sob encomenda",
        "Costureira de reparação de roupas",
        "Costureiro de roupa de couro e pele",
        "Auxiliar de corte (preparação da confecção de roupas)",
        "Cortador de roupas",
        "Enfestador de roupas",
        "Riscador de roupas",
        "Ajudante de confecção",
        "Costureiro de roupas de couro e pele, a  máquina na  confecção em série",
        "Costureiro na confecção em série",
        "Costureiro, a  máquina  na confecção em série",
        "Arrematadeira",
        "Bordador, à máquina",
        "Marcador de peças confeccionadas para bordar",
        "Operador de máquina de costura de acabamento",
        "Passadeira de peças confeccionadas",
        "Trabalhador polivalente da confecção de calçados",
        "Cortador de calçados, a  máquina (exceto solas e palmilhas)",
        "Cortador de solas e palmilhas, a  máquina",
        "Preparador de calçados",
        "Preparador de solas e palmilhas",
        "Costurador de calçados, a  máquina",
        "Montador de calçados",
        "Acabador de calçados",
        "Confeccionador de artefatos de couro (exceto sapatos)",
        "Chapeleiro de senhoras",
        "Boneleiro",
        "Cortador de artefatos de couro (exceto roupas e calçados)",
        "Cortador de tapeçaria",
        "Colchoeiro (confecção de colchões)",
        "Confeccionador de brinquedos de pano",
        "Confeccionador de velas náuticas, barracas e toldos",
        "Estofador de aviões",
        "Estofador de móveis",
        "Tapeceiro de autos",
        "Costurador de artefatos de couro, a  máquina (exceto roupas e calçados)",
        "Montador de artefatos de couro (exceto roupas e calçados)",
        "Trabalhador do acabamento de artefatos de tecidos e couros",
        "Copiador de chapa",
        "Gravador de matriz para flexografia (clicherista)",
        "Editor de texto e imagem",
        "Montador de fotolito (analógico e digital)",
        "Gravador de matriz para rotogravura (eletromecânico e químico)",
        "Gravador de matriz calcográfica",
        "Gravador de matriz serigráfica",
        "Operador de sistemas de prova (analógico e digital)",
        "Operador de processo de tratamento de imagem",
        "Programador visual gráfico",
        "Impressor (serigrafia)",
        "Impressor calcográfico",
        "Impressor de ofsete (plano e rotativo)",
        "Impressor de rotativa",
        "Impressor de rotogravura",
        "Impressor digital",
        "Impressor flexográfico",
        "Impressor letterset",
        "Impressor tampográfico",
        "Impressor tipográfico",
        "Acabador de embalagens (flexíveis e cartotécnicas)",
        "Impressor de corte e vinco",
        "Operador de acabamento (indústria gráfica)",
        "Operador de guilhotina (corte de papel)",
        "Preparador de matrizes de corte e vinco",
        "Laboratorista fotográfico",
        "Revelador de filmes fotográficos, em preto e branco",
        "Revelador de filmes fotográficos, em cores",
        "Auxiliar de radiologia (revelação fotográfica)",
        "Tecelão (tear manual)",
        "Tecelão de tapetes, a  mão",
        "Tricoteiro, à mão",
        "Redeiro",
        "Chapeleiro (chapéus de palha)",
        "Crocheteiro, a  mão",
        "Bordador, a  mão",
        "Cerzidor",
        "Artífice do couro",
        "Cortador de calçados, a  mão (exceto solas)",
        "Costurador de artefatos de couro, a  mão (exceto roupas e calçados)",
        "Sapateiro (calçados sob medida)",
        "Seleiro",
        "Tipógrafo",
        "Linotipista",
        "Monotipista",
        "Paginador",
        "Pintor de letreiros",
        "Confeccionador de carimbos de borracha",
        "Gravador, à mão (encadernação)",
        "Restaurador de livros",
        "Mestre (indústria de madeira e mobiliário)",
        "Mestre carpinteiro",
        "Marceneiro",
        "Modelador de madeira",
        "Maquetista na marcenaria",
        "Tanoeiro",
        "Classificador de madeira",
        "Impregnador de madeira",
        "Secador de madeira",
        "Cortador de laminados de madeira",
        "Operador de serras no desdobramento de madeira",
        "Serrador de bordas no desdobramento de madeira",
        "Serrador de madeira",
        "Serrador de madeira (serra circular múltipla)",
        "Serrador de madeira (serra de fita múltipla)",
        "Operador de máquina intercaladora de placas (compensados)",
        "Prensista de aglomerados",
        "Prensista de compensados",
        "Preparador de aglomerantes",
        "Operador de desempenadeira na usinagem convencional de madeira",
        "Operador de entalhadeira (usinagem de madeira)",
        "Operador de fresadora (usinagem de madeira)",
        "Operador de lixadeira (usinagem de madeira)",
        "Operador de máquina de usinagem madeira, em geral",
        "Operador de molduradora (usinagem de madeira)",
        "Operador de plaina desengrossadeira",
        "Operador de serras (usinagem de madeira)",
        "Operador de torno automático (usinagem de madeira)",
        "Operador de tupia (usinagem de madeira)",
        "Torneiro na usinagem convencional de madeira",
        "Operador de máquina bordatriz",
        "Operador de máquina de cortina d´água (produção de móveis)",
        "Operador de máquina de usinagem de madeira (produção em série)",
        "Operador de prensa de alta freqüência na usinagem de madeira",
        "Operador de centro de usinagem de madeira (cnc)",
        "Operador de máquinas de usinar madeira (cnc)",
        "Montador de móveis e artefatos de madeira",
        "Entalhador  de madeira",
        "Folheador de móveis de madeira",
        "Lustrador de peças de madeira",
        "Marcheteiro",
        "Cesteiro",
        "Confeccionador de escovas, pincéis e produtos similares (a mão)",
        "Confeccionador de escovas, pincéis e produtos similares (a máquina)",
        "Confeccionador de móveis de vime, junco e bambu",
        "Esteireiro",
        "Vassoureiro",
        "Carpinteiro naval (construção de pequenas embarcações)",
        "Carpinteiro naval (embarcações)",
        "Carpinteiro naval (estaleiros)",
        "Carpinteiro de carretas",
        "Carpinteiro de carrocerias",
        "Supervisor de embalagem e etiquetagem",
        "Condutor de processos robotizados de pintura",
        "Condutor de processos robotizados de soldagem",
        "Operador de veículos subaquáticos controlados remotamente",
        "Operador de aeronaves não tripuladas",
        "Mergulhador profissional (raso e profundo)",
        "Operador de draga",
        "Operador de guindaste (fixo)",
        "Operador de guindaste móvel",
        "Operador de máquina rodoferroviária",
        "Operador de monta-cargas (construção civil)",
        "Operador de ponte rolante",
        "Operador de pórtico rolante",
        "Operador de talha elétrica",
        "Sinaleiro (ponte-rolante)",
        "Guincheiro (construção civil)",
        "Operador de docagem",
        "Operador de empilhadeira",
        "Motorista de carro de passeio",
        "Motorista de furgão ou veículo similar",
        "Motorista de táxi",
        "Condutor de ambulância",
        "Motorista de ônibus rodoviário",
        "Motorista de ônibus urbano",
        "Motorista de trólebus",
        "Caminhoneiro autônomo (rotas regionais e internacionais)",
        "Motorista de caminhão (rotas regionais e internacionais)",
        "Motorista operacional de guincho",
        "Operador de trem de metrô",
        "Maquinista de trem",
        "Maquinista de trem metropolitano",
        "Motorneiro",
        "Auxiliar de maquinista de trem",
        "Operador de teleférico (passageiros)",
        "Marinheiro de convés (marítimo e fluviário)",
        "Marinheiro de máquinas",
        "Moço de convés (marítimo e fluviário)",
        "Moço de máquinas (marítimo e fluviário)",
        "Marinheiro de esporte e recreio",
        "Marinheiro auxiliar de convés (marítimo e aquaviario)",
        "Marinheiro auxiliar de máquinas (marítimo e aquaviário)",
        "Condutor de veículos de tração animal (ruas e estradas)",
        "Tropeiro",
        "Boiadeiro",
        "Condutor de veículos a pedais",
        "Agente de pátio",
        "Manobrador",
        "Carregador (aeronaves)",
        "Carregador (armazém)",
        "Carregador (veículos de transportes terrestres)",
        "Estivador",
        "Ajudante de motorista",
        "Bloqueiro (trabalhador portuário)",
        "Trabalhador portuário de capatazia",
        "Amarrador e desamarrado de embarcações",
        "Embalador, a mão",
        "Embalador, a máquina",
        "Operador de máquina de etiquetar",
        "Operador de máquina de envasar líquidos",
        "Operador de prensa de enfardamento",
        "Alimentador de linha de produção",
        "Artesão bordador",
        "Artesão ceramista",
        "Artesão com material reciclável",
        "Artesão confeccionador de biojóias e ecojóias",
        "Artesão do couro",
        "Artesão escultor",
        "Artesão moveleiro (exceto reciclado)",
        "Artesão tecelão",
        "Artesão trançador",
        "Artesão crocheteiro",
        "Artesão tricoteiro",
        "Artesão rendeiro",
        "Mestre (indústria petroquímica e carboquímica)",
        "Mestre de produção química",
        "Mestre (indústria de borracha e plástico)",
        "Mestre de produção farmacêutica",
        "Operador de processos químicos e petroquímicos",
        "Operador de sala de controle de instalações químicas, petroquímicas e afins",
        "Moleiro (tratamentos químicos e afins)",
        "Operador de máquina misturadeira (tratamentos químicos e afins)",
        "Operador de britadeira (tratamentos químicos e afins)",
        "Operador de concentração",
        "Trabalhador da fabricação de resinas e vernizes",
        "Trabalhador de fabricação de tintas",
        "Operador de calcinação (tratamento químico e afins)",
        "Operador de tratamento químico de materiais radioativos",
        "Operador de centrifugadora (tratamentos químicos e afins)",
        "Operador de exploração de petróleo",
        "Operador de filtro de secagem (mineração)",
        "Operador de filtro de tambor rotativo (tratamentos químicos e afins)",
        "Operador de filtro-esteira (mineração)",
        "Operador de filtro-prensa (tratamentos químicos e afins)",
        "Operador de filtros de parafina (tratamentos químicos e afins)",
        "Destilador de madeira",
        "Destilador de produtos químicos (exceto petróleo)",
        "Operador de alambique de funcionamento contínuo (produtos químicos, exceto petróleo)",
        "Operador de aparelho de reação e conversão (produtos químicos, exceto petróleo)",
        "Operador de equipamento de destilação de álcool",
        "Operador de evaporador na destilação",
        "Operador de painel de controle (refinação de petróleo)",
        "Operador de transferência e estocagem - na refinação do petróleo",
        "Operador de britador de coque",
        "Operador de carro de apagamento e coque",
        "Operador de destilação e subprodutos de coque",
        "Operador de enfornamento e desenfornamento de coque",
        "Operador de exaustor (coqueria)",
        "Operador de painel de controle",
        "Operador de preservação e controle térmico",
        "Operador de reator de coque de petróleo",
        "Operador de refrigeração (coqueria)",
        "Operador de sistema de reversão (coqueria)",
        "Bamburista",
        "Calandrista de borracha",
        "Confeccionador de pneumáticos",
        "Confeccionador de velas por imersão",
        "Confeccionador de velas por moldagem",
        "Laminador de plástico",
        "Moldador de borracha por compressão",
        "Moldador de plástico por compressão",
        "Moldador de plástico por injeção",
        "Trefilador de borracha",
        "Operador de máquina de produtos farmacêuticos",
        "Drageador (medicamentos)",
        "Operador de máquina de fabricação de cosméticos",
        "Operador de máquina de fabricação de produtos de higiene e limpeza"
        " (sabão, sabonete, detergente, absorvente, fraldas cotonetes e outros)",
        "Pirotécnico",
        "Trabalhador da fabricação de munição e explosivos",
        "Cilindrista (petroquímica e afins)",
        "Operador de calandra (química, petroquímica e afins)",
        "Operador de extrusora (química, petroquímica e afins)",
        "Operador de processo (química, petroquímica e afins)",
        "Operador de produção (química, petroquímica e afins)",
        "Técnico de operação (química, petroquímica e afins)",
        "Assistente de laboratório industrial",
        "Auxiliar de laboratório de análises físico-químicas",
        "Mestre de siderurgia",
        "Mestre de aciaria",
        "Mestre de alto-forno",
        "Mestre de forno elétrico",
        "Mestre de laminação",
        "Supervisor de fabricação de produtos cerâmicos, porcelanatos e afins",
        "Supervisor de fabricação de produtos de vidro",
        "Operador de centro de controle ( sinterização)",
        "Operador de máquina de sinterizar",
        "Forneiro e operador (alto-forno)",
        "Forneiro e operador (conversor a oxigênio)",
        "Forneiro e operador (forno elétrico)",
        "Forneiro e operador (refino de metais não-ferrosos)",
        "Forneiro e operador de forno de redução direta",
        "Operador de aciaria (basculamento de convertedor)",
        "Operador de aciaria (dessulfuração de gusa)",
        "Operador de aciaria (recebimento de gusa)",
        "Operador de área de corrida",
        "Operador de desgaseificação",
        "Soprador de convertedor",
        "Operador de laminador",
        "Operador de laminador de barras a frio",
        "Operador de laminador de barras a quente",
        "Operador de laminador de metais não-ferrosos",
        "Operador de laminador de tubos",
        "Operador de montagem de cilindros e mancais",
        "Recuperador de guias e cilindros",
        "Encarregado de acabamento de chapas e metais  (têmpera)",
        "Escarfador",
        "Marcador de produtos (siderúrgico e metalúrgico)",
        "Operador de bobinadeira de tiras a quente, no acabamento de chapas e metais",
        "Operador de cabine de laminação (fio-máquina)",
        "Operador de escória e sucata",
        "Operador de jato abrasivo",
        "Operador de tesoura mecânica e máquina de corte, no acabamento de chapas e metais",
        "Preparador de sucata e aparas",
        "Rebarbador de metal",
        "Forneiro de cubilô",
        "Forneiro de forno-poço",
        "Forneiro de fundição (forno de redução)",
        "Forneiro de reaquecimento e tratamento térmico na metalurgia",
        "Forneiro de revérbero",
        "Preparador de massa (fabricação de abrasivos)",
        "Preparador de massa (fabricação de vidro)",
        "Preparador de massa de argila",
        "Preparador de barbotina",
        "Preparador de esmaltes (cerâmica)",
        "Preparador de aditivos",
        "Operador de atomizador",
        "Extrusor de fios ou fibras de vidro",
        "Forneiro na fundição de vidro",
        "Forneiro no recozimento de vidro",
        "Moldador de abrasivos na fabricação de cerâmica, vidro e porcelana",
        "Operador de banho metálico de vidro por flutuação",
        "Operador de máquina de soprar vidro",
        "Operador de máquina extrusora de varetas e tubos de vidro",
        "Operador de prensa de moldar vidro",
        "Temperador de vidro",
        "Trabalhador na fabricação de produtos abrasivos",
        "Classificador e empilhador de tijolos refratários",
        "Forneiro (materiais de construção)",
        "Trabalhador da elaboração de pré-fabricados (cimento amianto)",
        "Trabalhador da elaboração de pré-fabricados (concreto armado)",
        "Trabalhador da fabricação de pedras artificiais",
        "Oleiro (fabricação de telhas)",
        "Oleiro (fabricação de tijolos)",
        "Mestre (indústria de celulose, papel e papelão)",
        "Cilindreiro na preparação de pasta para fabricação de papel",
        "Operador de branqueador de pasta para fabricação de papel",
        "Operador de digestor de pasta para fabricação de papel",
        "Operador de lavagem e depuração de pasta para fabricação de papel",
        "Operador de máquina de secar celulose",
        "Calandrista de papel",
        "Operador de cortadeira de papel",
        "Operador de máquina de fabricar papel  (fase úmida)",
        "Operador de máquina de fabricar papel (fase seca)",
        "Operador de máquina de fabricar papel e papelão",
        "Operador de rebobinadeira na fabricação de papel e papelão",
        "Cartonageiro, a máquina",
        "Confeccionador de bolsas, sacos e sacolas e papel, a máquina",
        "Confeccionador de sacos de celofane, a máquina",
        "Operador de máquina de cortar e dobrar papelão",
        "Operador de prensa de embutir papelão",
        "Cartonageiro, a mão (caixas de papelão)",
        "Supervisor de produção da indústria alimentícia",
        "Supervisor da indústria de bebidas",
        "Supervisor da indústria de fumo",
        "Chefe de confeitaria",
        "Moleiro de cereais (exceto arroz)",
        "Moleiro de especiarias",
        "Operador de processo de moagem",
        "Moedor de sal",
        "Refinador de sal",
        "Operador de cristalização na refinação de açucar",
        "Operador de equipamentos de refinação de açúcar (processo contínuo)",
        "Operador de moenda na fabricação de açúcar",
        "Operador de tratamento de calda na refinação de açúcar",
        "Cozinhador (conservação de alimentos)",
        "Cozinhador de carnes",
        "Cozinhador de frutas e legumes",
        "Cozinhador de pescado",
        "Desidratador de alimentos",
        "Esterilizador de alimentos",
        "Hidrogenador de óleos e gorduras",
        "Lagareiro",
        "Operador de câmaras frias",
        "Operador de preparação de grãos vegetais (óleos e gorduras)",
        "Prensador de frutas (exceto oleaginosas)",
        "Preparador de rações",
        "Refinador de óleo e gordura",
        "Trabalhador de fabricação de margarina",
        "Trabalhador de preparação de pescados (limpeza)",
        "Trabalhador de tratamento do leite e fabricação de laticínios e afins",
        "Misturador de café",
        "Torrador de café",
        "Moedor de café",
        "Operador de extração de café solúvel",
        "Torrador de cacau",
        "Misturador de chá ou mate",
        "Alambiqueiro",
        "Filtrador de cerveja",
        "Fermentador",
        "Trabalhador de fabricação de vinhos",
        "Malteiro (germinação)",
        "Cozinhador de malte",
        "Dessecador de malte",
        "Vinagreiro",
        "Xaropeiro",
        "Operador de forno (fabricação de pães, biscoitos e similares)",
        "Operador de máquinas de fabricação de doces, salgados e massas alimentícias",
        "Operador de máquinas de fabricação de chocolates e achocolatados",
        "Preparador de melado e essência de fumo",
        "Processador de fumo",
        "Classificador de fumo",
        "Auxiliar de processamento de fumo",
        "Operador de máquina (fabricação de cigarros)",
        "Operador de máquina de preparação de matéria prima para produção de cigarros",
        "Preparador de fumo na fabricação de charutos",
        "Operador de máquina de fabricar charutos e cigarrilhas",
        "Classificador de charutos",
        "Cortador de charutos",
        "Celofanista na fabricação de charutos",
        "Charuteiro a mão",
        "Degustador de charutos",
        "Defumador de carnes e pescados",
        "Salgador de alimentos",
        "Salsicheiro (fabricação de lingüiça, salsicha e produtos similares)",
        "Pasteurizador",
        "Queijeiro na fabricação de laticínio",
        "Manteigueiro na fabricação de laticínio",
        "Padeiro",
        "Confeiteiro",
        "Masseiro (massas alimentícias)",
        "Trabalhador de fabricação de sorvete",
        "Degustador de café",
        "Degustador de chá",
        "Degustador de derivados de cacau",
        "Degustador de vinhos ou licores",
        "Classificador de grãos",
        "Abatedor",
        "Açougueiro",
        "Desossador",
        "Magarefe",
        "Retalhador de carne",
        "Trabalhador do beneficiamento de fumo",
        "Supervisor de manutenção eletromecânica (utilidades)",
        "Supervisor de operação de fluidos (distribuição, captação, tratamento de água, gases, vapor)",
        "Supervisor de operação elétrica (geração, transmissão e distribuição de energia elétrica)",
        "Operador de central hidrelétrica",
        "Operador de quadro de distribuição de energia elétrica",
        "Operador de central termoelétrica",
        "Operador de reator nuclear",
        "Operador de subestação",
        "Foguista (locomotivas a vapor)",
        "Maquinista de embarcações",
        "Operador de bateria de gás de hulha",
        "Operador de caldeira",
        "Operador de compressor de ar",
        "Operador de estação de bombeamento",
        "Operador de máquinas fixas, em geral",
        "Operador de utilidade (produção e distribuição de vapor, gás, óleo, combustível, energia, oxigênio)",
        "Operador de abastecimento de combustível de aeronave",
        "Operador de estação de captação, tratamento e distribuição de água",
        "Operador de estação de tratamento de água e efluentes",
        "Operador de forno de incineração no tratamento de água, efluentes e resíduos industriais",
        "Operador de instalação de extração, processamento, envasamento e distribuição de gases",
        "Operador de instalação de refrigeração",
        "Operador de refrigeração com amônia",
        "Operador de instalação de ar-condicionado",
        "Encarregado de manutenção mecânica de sistemas operacionais",
        "Supervisor de manutenção de aparelhos térmicos, de climatização e de refrigeração",
        "Supervisor de manutenção de bombas, motores, compressores e equipamentos de transmissão",
        "Supervisor de manutenção de máquinas gráficas",
        "Supervisor de manutenção de máquinas industriais têxteis",
        "Supervisor de manutenção de máquinas operatrizes e de usinagem",
        "Supervisor da manutenção e reparação de veículos leves",
        "Supervisor da manutenção e reparação de veículos pesados",
        "Supervisor de reparos linhas férreas",
        "Supervisor de manutenção de vias férreas",
        "Mecânico de manutenção de bomba injetora (exceto de veículos automotores)",
        "Mecânico de manutenção de bombas",
        "Mecânico de manutenção de compressores de ar",
        "Mecânico de manutenção de motores diesel (exceto de veículos automotores)",
        "Mecânico de manutenção de redutores",
        "Mecânico de manutenção de turbinas (exceto de aeronaves)",
        "Mecânico de manutenção de turbocompressores",
        "Mecânico de manutenção e instalação de aparelhos de climatização e  refrigeração",
        "Mecânico de manutenção de máquinas, em geral",
        "Mecânico de manutenção de máquinas gráficas",
        "Mecânico de manutenção de máquinas operatrizes (lavra de madeira)",
        "Mecânico de manutenção de máquinas têxteis",
        "Mecânico de manutenção de máquinas-ferramentas (usinagem de metais)",
        "Mecânico de manutenção de aparelhos de levantamento",
        "Mecânico de manutenção de equipamento de mineração",
        "Mecânico de manutenção de máquinas agrícolas",
        "Mecânico de manutenção de máquinas de construção e terraplenagem",
        "Vulcanizador de correias transportadoras",
        "Mecânico de manutenção de aeronaves, em geral",
        "Mecânico de manutenção de sistema hidráulico de aeronaves (serviços de pista e hangar)",
        "Mecânico de manutenção de motores e equipamentos navais",
        "Mecânico de manutenção de veículos ferroviários",
        "Mecânico de manutenção de automóveis, motocicletas e veículos similares",
        "Mecânico de manutenção de empilhadeiras e outros veículos de cargas leves",
        "Mecânico de manutenção de motocicletas",
        "Mecânico de manutenção de tratores",
        "Mecânico de veículos automotores a diesel (exceto tratores)",
        "Técnico em manutenção de instrumentos de medição e precisão",
        "Técnico em manutenção de hidrômetros",
        "Técnico em manutenção de balanças",
        "Restaurador de instrumentos musicais (exceto cordas arcadas)",
        "Reparador de instrumentos musicais",
        "Luthier (restauração de cordas arcadas)",
        "Técnico em manutenção de equipamentos e instrumentos médico-hospitalares",
        "Reparador de equipamentos fotográficos",
        "Lubrificador industrial",
        "Lubrificador de veículos automotores (exceto embarcações)",
        "Lubrificador de embarcações",
        "Mecânico de manutenção de máquinas cortadoras de grama, roçadeiras, motosserras e similares",
        "Mecânico de manutenção de aparelhos esportivos e de ginástica",
        "Mecânico de manutenção de bicicletas e veículos similares",
        "Montador de bicicletas",
        "Supervisor de manutenção elétrica de alta tensão industrial",
        "Supervisor de manutenção eletromecânica industrial, comercial e predial",
        "Encarregado de manutenção elétrica de veículos",
        "Supervisor de manutenção eletromecânica",
        "Eletricista de manutenção eletroeletrônica",
        "Instalador de sistemas eletroeletrônicos de segurança",
        "Mantenedor de sistemas eletroeletrônicos de segurança",
        "Monitor de sistemas eletrônicos de segurança interno",
        "Monitor de sistemas eletrônicos de segurança externo",
        "Eletricista de instalações (aeronaves)",
        "Eletricista de instalações (embarcações)",
        "Eletricista de instalações (veículos automotores e máquinas operatrizes, exceto aeronaves e embarcações)",
        "Eletromecânico de manutenção de elevadores",
        "Eletromecânico de manutenção de escadas rolantes",
        "Eletromecânico de manutenção de portas automáticas",
        "Mecânico de manutenção de instalações mecânicas de edifícios",
        "Operador eletromecânico",
        "Reparador de aparelhos eletrodomésticos (exceto imagem e som)",
        "Reparador de rádio, tv e som",
        "Reparador de equipamentos de escritório",
        "Conservador de via permanente (trilhos)",
        "Inspetor de via permanente (trilhos)",
        "Operador de máquinas especiais em conservação de via permanente (trilhos)",
        "Soldador aluminotérmico em conservação de trilhos",
        "Mantenedor de equipamentos de parques de diversões e similares",
        "Funileiro de veículos (reparação)",
        "Montador de veículos (reparação)",
        "Pintor de veículos (reparação)",
        "Alinhador de pneus",
        "Balanceador",
        "Borracheiro",
        "Lavador de peças",
        "Encarregado geral de operações de conservação de vias permanentes (exceto trilhos)",
        "Encarregado de equipe de conservação de vias permanentes (exceto trilhos)",
        "Operador de ceifadeira na conservação de vias permanentes",
        "Pedreiro de conservação de vias permanentes (exceto trilhos)",
        "Auxiliar geral de conservação de vias permanentes (exceto trilhos)",
    ]
